<?php

/**
 * 客户订单历史
 * 用于查看和分析客户历史订单
 */

session_start();
require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 设置页面标题
$page_title = "客户订单历史";

// 初始化变量
$success = '';
$error = '';

// 获取筛选参数
$customer_id = isset($_GET['customer_id']) ? intval($_GET['customer_id']) : 0;
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : '';
$status = isset($_GET['status']) ? $_GET['status'] : '';

try {
    // 检查order_items表是否存在
    $stmt = $pdo->query("SHOW TABLES LIKE 'order_items'");
    if (!$stmt->rowCount()) {
        // 从SQL文件中提取order_items表定义并创建
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        if (preg_match('/CREATE TABLE\s+`order_items`\s*\((.*?)\)\s*ENGINE/s', $sql_file, $matches)) {
            $create_order_items_sql = "CREATE TABLE `order_items` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '订单项目表'";
            $pdo->exec($create_order_items_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`order_items`(.*?);/s', $sql_file, $insert_matches)) {
                $insert_order_items_sql = "INSERT INTO `order_items`" . $insert_matches[1];
                $pdo->exec($insert_order_items_sql);
                $success = "已从SQL文件创建order_items表并插入初始数据";
            }
        } else {
            // 如果在SQL文件中找不到定义，创建一个简单的表结构
            $pdo->exec("
                CREATE TABLE `order_items` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '订单项ID',
                  `order_id` INT UNSIGNED NOT NULL COMMENT '订单ID',
                  `product_id` INT UNSIGNED NOT NULL COMMENT '产品ID',
                  `quantity` DECIMAL(10, 2) NOT NULL COMMENT '数量',
                  `unit_price` DECIMAL(10, 2) NOT NULL COMMENT '单价',
                  `discount_percent` DECIMAL(5, 2) DEFAULT NULL COMMENT '折扣百分比',
                  `line_total` DECIMAL(10, 2) NOT NULL COMMENT '行项目总计',
                  PRIMARY KEY (`id`),
                  KEY `idx_order_item_order` (`order_id`),
                  KEY `idx_order_item_product` (`product_id`)
                ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '订单项目表'
            ");
            $success .= " 已创建order_items表";
        }
    }

    // 获取所有客户列表（用于筛选）
    $customers = $pdo->query("SELECT id, name FROM customers WHERE is_active = 1 ORDER BY name")->fetchAll(PDO::FETCH_ASSOC);

    // 构建订单查询
    $sql = "
        SELECT 
            so.id, 
            so.order_number,
            c.name AS customer_name,
            c.type AS customer_type,
            so.order_date,
            so.total_amount,
            so.status,
            so.shipping_address,
            so.notes,
            (SELECT COUNT(*) FROM order_items WHERE order_id = so.id) AS item_count
        FROM 
            sales_orders so
        JOIN 
            customers c ON so.customer_id = c.id
        WHERE 1=1";

    $params = [];

    if ($customer_id > 0) {
        $sql .= " AND so.customer_id = ?";
        $params[] = $customer_id;
    }

    if (!empty($start_date)) {
        $sql .= " AND so.order_date >= ?";
        $params[] = $start_date;
    }

    if (!empty($end_date)) {
        $sql .= " AND so.order_date <= ?";
        $params[] = $end_date;
    }

    if (!empty($status)) {
        $sql .= " AND so.status = ?";
        $params[] = $status;
    }

    $sql .= " ORDER BY so.order_date DESC, so.id DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $orders = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取订单详情（如果有指定查看的订单ID）
    $order_detail = null;
    $order_items = [];

    if (isset($_GET['view_order']) && intval($_GET['view_order']) > 0) {
        $order_id = intval($_GET['view_order']);

        // 获取订单详情
        $stmt = $pdo->prepare("
            SELECT 
                so.*,
                c.name AS customer_name,
                c.type AS customer_type,
                c.contact_person,
                c.phone,
                c.email,
                c.address AS customer_address,
                u.username AS created_by
            FROM 
                sales_orders so
            JOIN 
                customers c ON so.customer_id = c.id
            LEFT JOIN
                users u ON so.created_by_user_id = u.id
            WHERE 
                so.id = ?
        ");
        $stmt->execute([$order_id]);
        $order_detail = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($order_detail) {
            // 获取订单项
            $stmt = $pdo->prepare("
                SELECT 
                    oi.*,
                    p.name AS product_name,
                    p.specification AS sku,
                    p.unit AS unit_of_measure
                FROM 
                    order_items oi
                JOIN 
                    products p ON oi.product_id = p.id
                WHERE 
                    oi.order_id = ?
            ");
            $stmt->execute([$order_id]);
            $order_items = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
    }

    // 客户类型映射
    $customer_types = [
        'wholesale' => '批发客户',
        'retail' => '零售客户',
        'distributor' => '代理商',
        'ecommerce' => '电商客户'
    ];

    // 订单状态映射
    $order_statuses = [
        'pending' => '待处理',
        'processing' => '处理中',
        'shipped' => '已发货',
        'delivered' => '已送达',
        'completed' => '已完成',
        'cancelled' => '已取消',
        'refunded' => '已退款'
    ];
} catch (PDOException $e) {
    $error = "数据库错误：" . $e->getMessage();
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($page_title) ?> - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="content">
        <h1><?= htmlspecialchars($page_title) ?></h1>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <!-- 筛选条件 - 调整为与客户管理页面相同的样式 -->
        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <select name="customer_id" title="客户">
                    <option value="0">所有客户</option>
                    <?php foreach ($customers as $c): ?>
                        <option value="<?= $c['id'] ?>" <?= $customer_id === $c['id'] ? 'selected' : '' ?>>
                            <?= htmlspecialchars($c['name']) ?>
                        </option>
                    <?php endforeach; ?>
                </select>

                <select name="status" title="订单状态">
                    <option value="">所有状态</option>
                    <?php foreach ($order_statuses as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $status === $key ? 'selected' : '' ?>>
                            <?= $value ?>
                        </option>
                    <?php endforeach; ?>
                </select>

                <input type="date" id="start_date" name="start_date" title="开始日期" value="<?= htmlspecialchars($start_date) ?>">
                <input type="date" id="end_date" name="end_date" title="结束日期" value="<?= htmlspecialchars($end_date) ?>">

                <button type="submit">搜索</button>
                <button type="button" onclick="location.href='customer_order_history.php'" class="btn-secondary">重置</button>
            </form>
        </div>

        <!-- 如果正在查看订单详情，则显示详情页 -->
        <?php if ($order_detail): ?>
            <div class="order-detail-container">
                <div class="order-detail-header">
                    <h2>订单详情：<?= htmlspecialchars($order_detail['order_number']) ?></h2>
                    <a href="customer_order_history.php?<?= http_build_query(array_filter([
                                                            'customer_id' => $customer_id,
                                                            'start_date' => $start_date,
                                                            'end_date' => $end_date,
                                                            'status' => $status
                                                        ])) ?>" class="btn-secondary">返回列表</a>
                </div>

                <div class="card">
                    <div class="card-header">基本信息</div>
                    <div class="card-body">
                        <div class="card-row">
                            <div class="card-item">
                                <div class="card-label">订单号</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['order_number']) ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">订单日期</div>
                                <div class="card-value"><?= date('Y-m-d', strtotime($order_detail['order_date'])) ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">状态</div>
                                <div class="card-value">
                                    <span class="status-tag <?= $order_detail['status'] ?>">
                                        <?= isset($order_statuses[$order_detail['status']]) ? $order_statuses[$order_detail['status']] : $order_detail['status'] ?>
                                    </span>
                                </div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">总金额</div>
                                <div class="card-value">¥<?= number_format($order_detail['total_amount'], 2) ?></div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header">客户信息</div>
                    <div class="card-body">
                        <div class="card-row">
                            <div class="card-item">
                                <div class="card-label">客户名称</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['customer_name']) ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">客户类型</div>
                                <div class="card-value">
                                    <?= isset($customer_types[$order_detail['customer_type']]) ? $customer_types[$order_detail['customer_type']] : $order_detail['customer_type'] ?>
                                </div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">联系人</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['contact_person'] ?: '-') ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">联系电话</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['phone'] ?: '-') ?></div>
                            </div>
                        </div>

                        <div class="card-row">
                            <div class="card-item">
                                <div class="card-label">电子邮件</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['email'] ?: '-') ?></div>
                            </div>
                            <div class="card-item wide">
                                <div class="card-label">客户地址</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['customer_address'] ?: '-') ?></div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header">配送信息</div>
                    <div class="card-body">
                        <div class="card-row">
                            <div class="card-item wide">
                                <div class="card-label">配送地址</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['shipping_address'] ?: '-') ?></div>
                            </div>
                        </div>

                        <div class="card-row">
                            <div class="card-item wide">
                                <div class="card-label">备注</div>
                                <div class="card-value"><?= nl2br(htmlspecialchars($order_detail['notes'] ?: '-')) ?></div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header">订单项目</div>
                    <div class="card-body">
                        <?php if (empty($order_items)): ?>
                            <p>无订单项数据</p>
                        <?php else: ?>
                            <table>
                                <thead>
                                    <tr>
                                        <th>产品</th>
                                        <th>SKU</th>
                                        <th>数量</th>
                                        <th>单位</th>
                                        <th>单价</th>
                                        <th>折扣</th>
                                        <th>小计</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php foreach ($order_items as $item): ?>
                                        <tr>
                                            <td><?= htmlspecialchars($item['product_name']) ?></td>
                                            <td><?= htmlspecialchars($item['sku'] ?: '-') ?></td>
                                            <td><?= number_format($item['quantity'], 2) ?></td>
                                            <td><?= htmlspecialchars($item['unit_of_measure']) ?></td>
                                            <td>¥<?= number_format($item['unit_price'], 2) ?></td>
                                            <td><?= $item['discount_percent'] ? number_format($item['discount_percent'], 1) . '%' : '-' ?></td>
                                            <td>¥<?= number_format($item['line_total'], 2) ?></td>
                                        </tr>
                                    <?php endforeach; ?>
                                </tbody>
                                <tfoot>
                                    <tr>
                                        <td colspan="6" class="text-right"><strong>总计</strong></td>
                                        <td><strong>¥<?= number_format($order_detail['total_amount'], 2) ?></strong></td>
                                    </tr>
                                </tfoot>
                            </table>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="card">
                    <div class="card-header">其他信息</div>
                    <div class="card-body">
                        <div class="card-row">
                            <div class="card-item">
                                <div class="card-label">创建人</div>
                                <div class="card-value"><?= htmlspecialchars($order_detail['created_by'] ?: '-') ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">创建时间</div>
                                <div class="card-value"><?= date('Y-m-d H:i', strtotime($order_detail['created_at'])) ?></div>
                            </div>
                            <div class="card-item">
                                <div class="card-label">最后更新</div>
                                <div class="card-value"><?= date('Y-m-d H:i', strtotime($order_detail['updated_at'])) ?></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <!-- 订单列表 -->
            <div class="table-container">
                <h2>订单列表</h2>
                <?php if (empty($orders)): ?>
                    <div class="empty-state">
                        <p>暂无订单数据</p>
                    </div>
                <?php else: ?>
                    <table>
                        <thead>
                            <tr>
                                <th>订单号</th>
                                <th>客户</th>
                                <th>客户类型</th>
                                <th>日期</th>
                                <th>项目数</th>
                                <th>金额</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?= htmlspecialchars($order['order_number']) ?></td>
                                    <td><?= htmlspecialchars($order['customer_name']) ?></td>
                                    <td><?= isset($customer_types[$order['customer_type']]) ? $customer_types[$order['customer_type']] : $order['customer_type'] ?></td>
                                    <td><?= date('Y-m-d', strtotime($order['order_date'])) ?></td>
                                    <td><?= $order['item_count'] ?></td>
                                    <td>¥<?= number_format($order['total_amount'], 2) ?></td>
                                    <td>
                                        <span class="status-tag <?= $order['status'] ?>">
                                            <?= isset($order_statuses[$order['status']]) ? $order_statuses[$order['status']] : $order['status'] ?>
                                        </span>
                                    </td>
                                    <td>
                                        <a href="?view_order=<?= $order['id'] ?>&<?= http_build_query(array_filter([
                                                                                        'customer_id' => $customer_id,
                                                                                        'start_date' => $start_date,
                                                                                        'end_date' => $end_date,
                                                                                        'status' => $status
                                                                                    ])) ?>" class="btn-view">查看</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php endif; ?>
            </div>
        <?php endif; ?>
    </div>

    <style>
        /* 补充样式 */
        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .filter-container {
            margin-bottom: 20px;
        }

        .search-bar {
            display: flex;
            flex-wrap: wrap;
            gap: 10px;
            align-items: center;
        }

        .search-bar input,
        .search-bar select {
            padding: 8px 12px;
            border: 1px solid #ddd;
            border-radius: 4px;
            flex: 1;
        }

        .search-bar button {
            padding: 8px 16px;
            border: none;
            border-radius: 4px;
            background-color: #3498db;
            color: white;
            cursor: pointer;
        }

        .search-bar button.btn-secondary {
            background-color: #6c757d;
        }

        .order-detail-container {
            margin-top: 20px;
        }

        .order-detail-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .card {
            border: 1px solid #ddd;
            border-radius: 5px;
            margin-bottom: 20px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
        }

        .card-header {
            background-color: #f5f5f5;
            padding: 10px 15px;
            border-bottom: 1px solid #ddd;
            font-weight: bold;
        }

        .card-body {
            padding: 15px;
        }

        .card-row {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 10px;
        }

        .card-item {
            flex: 1;
            min-width: 200px;
            margin-bottom: 10px;
            padding-right: 20px;
        }

        .card-item.wide {
            flex: 2;
            min-width: 400px;
        }

        .card-label {
            font-size: 0.85em;
            color: #666;
            margin-bottom: 5px;
        }

        .card-value {
            font-weight: 500;
        }

        .text-right {
            text-align: right;
        }

        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 3px;
            font-size: 0.85em;
            font-weight: 500;
            color: white;
        }

        .status-tag.pending {
            background-color: #f39c12;
        }

        .status-tag.processing {
            background-color: #3498db;
        }

        .status-tag.shipped {
            background-color: #2ecc71;
        }

        .status-tag.delivered {
            background-color: #27ae60;
        }

        .status-tag.completed {
            background-color: #16a085;
        }

        .status-tag.cancelled {
            background-color: #e74c3c;
        }

        .status-tag.refunded {
            background-color: #9b59b6;
        }

        .btn-view {
            display: inline-block;
            padding: 4px 8px;
            background-color: #3498db;
            color: white;
            text-decoration: none;
            border-radius: 4px;
            font-size: 13px;
        }

        @media (max-width: 768px) {
            .search-bar {
                flex-direction: column;
                align-items: stretch;
            }

            .card-item,
            .card-item.wide {
                flex: 100%;
                min-width: 100%;
            }
        }
    </style>
</body>

</html>