<?php
// finance/purchase_cost_analysis.php - 采购成本核算页面
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查并创建必要的数据表
try {
    // 使用config.php中的$pdo变量

    // 注意: 在FruitEase.sql中没有定义"materials"表
    // 原料数据存储在"products"表中，类型为'raw'

    // 检查材料采购表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'material_purchases'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建材料采购表
        $sql = "CREATE TABLE material_purchases (
            id INT AUTO_INCREMENT PRIMARY KEY,
            material_id INT NOT NULL,
            supplier_id INT NOT NULL,
            purchase_date DATE NOT NULL,
            quantity DECIMAL(10,2) NOT NULL,
            unit_price DECIMAL(10,2) NOT NULL,
            total_price DECIMAL(10,2) NOT NULL,
            notes TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    }

    // 检查人工成本表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'labor_costs'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建人工成本表
        $sql = "CREATE TABLE labor_costs (
            id INT AUTO_INCREMENT PRIMARY KEY,
            department_id INT NOT NULL,
            cost_date DATE NOT NULL,
            work_hours DECIMAL(10,2) NOT NULL,
            hourly_rate DECIMAL(10,2) NOT NULL,
            total_cost DECIMAL(10,2) NOT NULL,
            notes TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    }

    // 检查departments表是否存在，先创建这个表再进行查询
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'departments'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建departments表
        $sql = "CREATE TABLE departments (
            id INT AUTO_INCREMENT PRIMARY KEY,
            name VARCHAR(100) NOT NULL,
            description TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);

        // 插入一些示例部门
        $sql = "INSERT INTO departments (name, description) VALUES 
                ('生产部', '负责产品生产和加工'),
                ('质检部', '负责质量控制和检测'),
                ('仓储部', '负责仓库管理和物流')";
        $pdo->exec($sql);
    }

    // 检查设备折旧表是否存在
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'equipment_depreciation'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建设备折旧表
        $sql = "CREATE TABLE equipment_depreciation (
            id INT AUTO_INCREMENT PRIMARY KEY,
            equipment_id INT NOT NULL,
            purchase_cost DECIMAL(10,2) NOT NULL,
            salvage_value DECIMAL(10,2) NOT NULL,
            useful_life_years INT NOT NULL,
            depreciation_method ENUM('straight_line', 'declining_balance', 'units_of_production') NOT NULL,
            annual_depreciation DECIMAL(10,2) NOT NULL,
            start_date DATE NOT NULL,
            notes TEXT,
            created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
            updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP
        )";
        $pdo->exec($sql);
    }

    // 获取原料采购数据（过去12个月）- 使用products表而不是materials表
    $stmt = $pdo->prepare("
        SELECT 
            mp.*, 
            p.name AS material_name,
            s.name AS supplier_name
        FROM 
            material_purchases mp
        LEFT JOIN 
            products p ON mp.material_id = p.id
        LEFT JOIN 
            suppliers s ON mp.supplier_id = s.id
        WHERE 
            mp.purchase_date >= DATE_SUB(CURDATE(), INTERVAL 12 MONTH)
        ORDER BY 
            mp.purchase_date DESC
    ");
    $stmt->execute();
    $materialPurchases = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 作为备用方案，如果没有material_purchases数据，使用purchase_order_items显示采购数据
    if (empty($materialPurchases)) {
        $stmt = $pdo->prepare("
            SELECT 
                poi.*, 
                po.order_date AS purchase_date,
                p.name AS material_name,
                s.name AS supplier_name,
                poi.unit_price,
                poi.quantity,
                poi.item_total_amount AS total_price
            FROM 
                purchase_order_items poi
            JOIN 
                purchase_orders po ON poi.purchase_order_id = po.id
            JOIN 
                products p ON poi.product_id = p.id
            JOIN 
                suppliers s ON po.supplier_id = s.id
            WHERE 
                p.type = 'raw'
                AND po.order_date >= DATE_SUB(CURDATE(), INTERVAL 12 MONTH)
            ORDER BY 
                po.order_date DESC
        ");
        $stmt->execute();
        $materialPurchases = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // 获取人工成本数据（过去12个月）
    $stmt = $pdo->prepare("
        SELECT 
            lc.*,
            d.name AS department_name
        FROM 
            labor_costs lc
        LEFT JOIN 
            departments d ON lc.department_id = d.id
        WHERE 
            lc.cost_date >= DATE_SUB(CURDATE(), INTERVAL 12 MONTH)
        ORDER BY 
            lc.cost_date DESC
    ");
    $stmt->execute();
    $laborCosts = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取设备折旧数据
    $stmt = $pdo->prepare("
        SELECT 
            ed.*,
            e.name AS equipment_name
        FROM 
            equipment_depreciation ed
        LEFT JOIN 
            equipment e ON ed.equipment_id = e.id
        ORDER BY 
            ed.start_date DESC
    ");
    $stmt->execute();
    $equipmentDepreciation = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 如果没有折旧数据但有设备数据，创建一些示例折旧数据
    if (empty($equipmentDepreciation)) {
        // 获取设备数据
        $stmt = $pdo->prepare("SELECT * FROM equipment LIMIT 10");
        $stmt->execute();
        $equipment = $stmt->fetchAll(PDO::FETCH_ASSOC);

        if (!empty($equipment) && empty($equipmentDepreciation)) {
            // 为每个设备创建折旧记录
            foreach ($equipment as $equip) {
                $stmt = $pdo->prepare("
                    INSERT INTO equipment_depreciation 
                    (equipment_id, purchase_cost, salvage_value, useful_life_years, 
                     depreciation_method, annual_depreciation, start_date) 
                    VALUES (?, ?, ?, ?, ?, ?, ?)
                ");

                // 随机生成一些合理的折旧数据
                $purchaseCost = rand(10000, 100000);
                $salvageValue = $purchaseCost * 0.1;
                $usefulLife = rand(5, 15);
                $annualDepreciation = ($purchaseCost - $salvageValue) / $usefulLife;

                $stmt->execute([
                    $equip['id'],
                    $purchaseCost,
                    $salvageValue,
                    $usefulLife,
                    'straight_line',
                    $annualDepreciation,
                    date('Y-m-d', strtotime('-' . rand(1, 12) . ' months'))
                ]);
            }

            // 重新查询折旧数据
            $stmt = $pdo->prepare("
                SELECT 
                    ed.*,
                    e.name AS equipment_name
                FROM 
                    equipment_depreciation ed
                LEFT JOIN 
                    equipment e ON ed.equipment_id = e.id
                ORDER BY 
                    ed.start_date DESC
            ");
            $stmt->execute();
            $equipmentDepreciation = $stmt->fetchAll(PDO::FETCH_ASSOC);
        }
    }

    // 计算总成本
    $totalMaterialCost = 0;
    foreach ($materialPurchases as $purchase) {
        $totalMaterialCost += isset($purchase['total_price']) ? $purchase['total_price'] : 0;
    }

    $totalLaborCost = 0;
    foreach ($laborCosts as $labor) {
        $totalLaborCost += isset($labor['total_cost']) ? $labor['total_cost'] : 0;
    }

    $totalDepreciation = 0;
    foreach ($equipmentDepreciation as $depreciation) {
        $totalDepreciation += isset($depreciation['annual_depreciation']) ? $depreciation['annual_depreciation'] : 0;
    }

    $totalCost = $totalMaterialCost + $totalLaborCost + $totalDepreciation;
} catch (PDOException $e) {
    $error = "数据库错误: " . $e->getMessage();
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>采购成本核算 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <!-- <script src="https://cdn.bootcdn.net/ajax/libs/Chart.js/3.9.1/chart.min.js"></script> -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <style>
        .dashboard {
            display: grid;
            grid-template-columns: repeat(3, 1fr);
            gap: 20px;
            margin-bottom: 30px;
        }

        .card {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            text-align: center;
        }

        .card h3 {
            color: #555;
            font-size: 16px;
            margin-bottom: 10px;
        }

        .card .value {
            color: #2c3e50;
            font-size: 24px;
            font-weight: bold;
        }

        .chart-container {
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            padding: 20px;
            padding-bottom: 100px;
            margin-bottom: 30px;
            min-height: 450px;
        }

        .tab-container {
            margin-top: 20px;
        }

        .tabs {
            display: flex;
            border-bottom: 1px solid #ddd;
            margin-bottom: 20px;
        }

        .tab {
            padding: 10px 20px;
            cursor: pointer;
            border: 1px solid transparent;
            border-bottom: none;
            border-radius: 4px 4px 0 0;
            margin-right: 5px;
        }

        .tab.active {
            background: #fff;
            border-color: #ddd;
            border-bottom: 1px solid #fff;
            margin-bottom: -1px;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>采购成本核算</h1>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php else: ?>
            <!-- 成本概览 -->
            <section class="dashboard">
                <div class="card">
                    <h3>原料采购成本</h3>
                    <div class="value"><?= number_format($totalMaterialCost, 2) ?> 元</div>
                </div>
                <div class="card">
                    <h3>人工成本</h3>
                    <div class="value"><?= number_format($totalLaborCost, 2) ?> 元</div>
                </div>
                <div class="card">
                    <h3>设备折旧</h3>
                    <div class="value"><?= number_format($totalDepreciation, 2) ?> 元</div>
                </div>
            </section>

            <!-- 成本图表 -->
            <section class="chart-container">
                <h2>成本分布</h2>
                <canvas id="costDistributionChart"></canvas>
            </section>

            <!-- 成本详情标签页 -->
            <section class="tab-container">
                <div class="tabs">
                    <div class="tab active" onclick="openTab(event, 'materialTab')">原料采购</div>
                    <div class="tab" onclick="openTab(event, 'laborTab')">人工成本</div>
                    <div class="tab" onclick="openTab(event, 'depreciationTab')">设备折旧</div>
                </div>

                <!-- 原料采购标签内容 -->
                <div id="materialTab" class="tab-content active">
                    <h2>原料采购明细</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>材料名称</th>
                                <th>供应商</th>
                                <th>采购日期</th>
                                <th>数量</th>
                                <th>单价 (元)</th>
                                <th>总价 (元)</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($materialPurchases) > 0): ?>
                                <?php foreach ($materialPurchases as $purchase): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($purchase['material_name'] ?? '未知材料') ?></td>
                                        <td><?= htmlspecialchars($purchase['supplier_name'] ?? '未知供应商') ?></td>
                                        <td><?= htmlspecialchars($purchase['purchase_date']) ?></td>
                                        <td><?= htmlspecialchars($purchase['quantity']) ?></td>
                                        <td><?= number_format($purchase['unit_price'], 2) ?></td>
                                        <td><?= number_format($purchase['total_price'], 2) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无采购记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 人工成本标签内容 -->
                <div id="laborTab" class="tab-content">
                    <h2>人工成本明细</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>部门</th>
                                <th>日期</th>
                                <th>工作小时</th>
                                <th>小时工资 (元)</th>
                                <th>总成本 (元)</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($laborCosts) > 0): ?>
                                <?php foreach ($laborCosts as $labor): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($labor['department_name'] ?? '未知部门') ?></td>
                                        <td><?= htmlspecialchars($labor['cost_date']) ?></td>
                                        <td><?= htmlspecialchars($labor['work_hours']) ?></td>
                                        <td><?= number_format($labor['hourly_rate'], 2) ?></td>
                                        <td><?= number_format($labor['total_cost'], 2) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无人工成本记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>

                <!-- 设备折旧标签内容 -->
                <div id="depreciationTab" class="tab-content">
                    <h2>设备折旧明细</h2>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>设备名称</th>
                                <th>购买成本 (元)</th>
                                <th>残值 (元)</th>
                                <th>使用年限</th>
                                <th>折旧方法</th>
                                <th>年折旧 (元)</th>
                                <th>开始日期</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (count($equipmentDepreciation) > 0): ?>
                                <?php foreach ($equipmentDepreciation as $depreciation): ?>
                                    <tr>
                                        <td><?= htmlspecialchars($depreciation['equipment_name'] ?? '未知设备') ?></td>
                                        <td><?= number_format($depreciation['purchase_cost'], 2) ?></td>
                                        <td><?= number_format($depreciation['salvage_value'], 2) ?></td>
                                        <td><?= htmlspecialchars($depreciation['useful_life_years']) ?></td>
                                        <td>
                                            <?php
                                            $method = $depreciation['depreciation_method'];
                                            $methods = [
                                                'straight_line' => '直线法',
                                                'declining_balance' => '余额递减法',
                                                'units_of_production' => '产量法'
                                            ];
                                            echo $methods[$method] ?? $method;
                                            ?>
                                        </td>
                                        <td><?= number_format($depreciation['annual_depreciation'], 2) ?></td>
                                        <td><?= htmlspecialchars($depreciation['start_date']) ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无设备折旧记录</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </section>
        <?php endif; ?>
    </div>

    <script>
        // 标签页切换
        function openTab(evt, tabId) {
            var i, tabContent, tabLinks;

            // 隐藏所有标签页内容
            tabContent = document.getElementsByClassName("tab-content");
            for (i = 0; i < tabContent.length; i++) {
                tabContent[i].className = tabContent[i].className.replace(" active", "");
            }

            // 移除所有标签的active状态
            tabLinks = document.getElementsByClassName("tab");
            for (i = 0; i < tabLinks.length; i++) {
                tabLinks[i].className = tabLinks[i].className.replace(" active", "");
            }

            // 显示当前标签页并添加active状态
            document.getElementById(tabId).className += " active";
            evt.currentTarget.className += " active";
        }

        // 成本分布图表
        document.addEventListener('DOMContentLoaded', function() {
            var ctx = document.getElementById('costDistributionChart').getContext('2d');

            var costData = {
                labels: ['原料采购', '人工成本', '设备折旧'],
                datasets: [{
                    label: '成本分布',
                    data: [
                        <?= $totalMaterialCost ?>,
                        <?= $totalLaborCost ?>,
                        <?= $totalDepreciation ?>
                    ],
                    backgroundColor: [
                        'rgba(255, 99, 132, 0.7)',
                        'rgba(54, 162, 235, 0.7)',
                        'rgba(255, 206, 86, 0.7)'
                    ],
                    borderColor: [
                        'rgba(255, 99, 132, 1)',
                        'rgba(54, 162, 235, 1)',
                        'rgba(255, 206, 86, 1)'
                    ],
                    borderWidth: 1
                }]
            };

            var options = {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    position: 'right'
                }
            };

            var chart = new Chart(ctx, {
                type: 'pie',
                data: costData,
                options: options
            });
        });
    </script>
</body>

</html>