<?php
session_start();
// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 包含数据库连接
require_once '../config.php';

// 确保CSRF令牌已生成
if (empty($_SESSION['csrf_token'])) {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
}

// 初始化参数
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : '2024-01-01';
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$customer_id = isset($_GET['customer_id']) ? $_GET['customer_id'] : '';
$supplier_id = isset($_GET['supplier_id']) ? $_GET['supplier_id'] : '';
$status = isset($_GET['status']) ? $_GET['status'] : '';
$type = isset($_GET['type']) ? $_GET['type'] : 'receivables'; // 默认显示应收账款

// 初始化错误和数据变量
$error = '';
$receivables = [];
$payables = [];
$payments_received = [];
$payments_made = [];
$customers = [];
$suppliers = [];

// 总计
$total_receivable = 0;
$total_payable = 0;
$total_received = 0;
$total_paid = 0;
$overdue_receivable = 0;
$overdue_payable = 0;

try {
    // 检查必要的表是否存在
    $required_tables = ['sales_orders', 'purchase_orders', 'customers', 'suppliers'];
    foreach ($required_tables as $table) {
        $stmt = $pdo->prepare("SHOW TABLES LIKE ?");
        $stmt->execute([$table]);
        if ($stmt->rowCount() == 0) {
            throw new Exception("表 $table 不存在，无法执行应收应付管理。");
        }
    }

    // 在创建表之前，先检查被引用表的结构
    $stmt = $pdo->prepare("SHOW COLUMNS FROM sales_orders LIKE 'id'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        throw new Exception("sales_orders表缺少id字段，无法创建外键");
    }

    $stmt = $pdo->prepare("SHOW COLUMNS FROM customers LIKE 'id'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        throw new Exception("customers表缺少id字段，无法创建外键");
    }

    // 检查receivables表是否存在，如不存在则创建
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'receivables'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        $pdo->exec("
            CREATE TABLE `receivables` (
                `id` INT AUTO_INCREMENT PRIMARY KEY,
                `sales_order_id` INT NOT NULL,
                `customer_id` INT NOT NULL,
                `invoice_number` VARCHAR(50) NOT NULL,
                `invoice_date` DATE NOT NULL,
                `due_date` DATE NOT NULL,
                `amount` DECIMAL(10,2) NOT NULL,
                `paid_amount` DECIMAL(10,2) DEFAULT 0.00,
                `balance` DECIMAL(10,2) AS (amount - paid_amount),
                `status` ENUM('pending', 'partial', 'paid', 'overdue') NOT NULL DEFAULT 'pending',
                `notes` TEXT,
                `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                INDEX `idx_sales_order` (`sales_order_id`),
                INDEX `idx_customer` (`customer_id`),
                INDEX `idx_status` (`status`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
        ");

        // 从现有销售订单创建应收账款记录
        $pdo->exec("
            INSERT INTO receivables (sales_order_id, customer_id, invoice_number, invoice_date, due_date, amount, status)
            SELECT 
                id, 
                customer_id, 
                CONCAT('INV-', order_number), 
                order_date, 
                DATE_ADD(order_date, INTERVAL 30 DAY), 
                total_amount,
                CASE 
                    WHEN DATE_ADD(order_date, INTERVAL 30 DAY) < CURRENT_DATE THEN 'overdue'
                    ELSE 'pending'
                END
            FROM sales_orders
            WHERE status IN ('confirmed', 'processing', 'shipped', 'delivered')
        ");
    }

    // 检查payables表是否存在，如不存在则创建
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'payables'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        // 创建表结构（不包含外键约束）
        $pdo->exec("
            CREATE TABLE `payables` (
                `id` INT AUTO_INCREMENT PRIMARY KEY,
                `purchase_order_id` INT NOT NULL,
                `supplier_id` INT NOT NULL,
                `invoice_number` VARCHAR(50) NOT NULL,
                `invoice_date` DATE NOT NULL,
                `due_date` DATE NOT NULL,
                `amount` DECIMAL(10,2) NOT NULL,
                `paid_amount` DECIMAL(10,2) DEFAULT 0.00,
                `balance` DECIMAL(10,2) AS (amount - paid_amount),
                `status` ENUM('pending', 'partial', 'paid', 'overdue') NOT NULL DEFAULT 'pending',
                `notes` TEXT,
                `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                `updated_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                INDEX `idx_purchase_order` (`purchase_order_id`),
                INDEX `idx_supplier` (`supplier_id`),
                INDEX `idx_status` (`status`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
        ");

        // 从现有采购订单创建应付账款记录
        $pdo->exec("
            INSERT INTO payables (purchase_order_id, supplier_id, invoice_number, invoice_date, due_date, amount, status)
            SELECT 
                id, 
                supplier_id, 
                CONCAT('PO-INV-', order_number), 
                order_date, 
                DATE_ADD(order_date, INTERVAL 30 DAY), 
                total_amount,
                CASE 
                    WHEN DATE_ADD(order_date, INTERVAL 30 DAY) < CURRENT_DATE THEN 'overdue'
                    ELSE 'pending'
                END
            FROM purchase_orders
            WHERE status IN ('confirmed', 'processing', 'received', 'completed')
        ");
    }

    // 检查payments_received表是否存在，如不存在则创建
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'payments_received'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        $pdo->exec("
            CREATE TABLE `payments_received` (
                `id` INT AUTO_INCREMENT PRIMARY KEY,
                `receivable_id` INT NOT NULL,
                `amount` DECIMAL(10,2) NOT NULL,
                `payment_date` DATE NOT NULL,
                `payment_method` VARCHAR(50) NOT NULL,
                `reference_number` VARCHAR(100),
                `notes` TEXT,
                `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                INDEX `idx_receivable` (`receivable_id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
        ");
    }

    // 检查payments_made表是否存在，如不存在则创建
    $stmt = $pdo->prepare("SHOW TABLES LIKE 'payments_made'");
    $stmt->execute();
    if ($stmt->rowCount() == 0) {
        $pdo->exec("
            CREATE TABLE `payments_made` (
                `id` INT AUTO_INCREMENT PRIMARY KEY,
                `payable_id` INT NOT NULL,
                `amount` DECIMAL(10,2) NOT NULL,
                `payment_date` DATE NOT NULL,
                `payment_method` VARCHAR(50) NOT NULL,
                `reference_number` VARCHAR(100),
                `notes` TEXT,
                `created_at` TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                INDEX `idx_payable` (`payable_id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci
        ");
    }

    // 获取所有客户（用于筛选）
    $stmt = $pdo->prepare("SELECT id, name FROM customers ORDER BY name");
    $stmt->execute();
    $customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取所有供应商（用于筛选）
    $stmt = $pdo->prepare("SELECT id, name FROM suppliers ORDER BY name");
    $stmt->execute();
    $suppliers = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // 获取应收账款数据
    if ($type == 'receivables') {
        $sql = "
            SELECT 
                r.id,
                r.invoice_number,
                r.invoice_date,
                r.due_date,
                r.amount,
                r.paid_amount,
                r.balance,
                r.status,
                c.name AS customer_name,
                so.order_number AS sales_order_number
            FROM 
                receivables r
            JOIN 
                customers c ON r.customer_id = c.id
            JOIN 
                sales_orders so ON r.sales_order_id = so.id
            WHERE 
                r.invoice_date BETWEEN :start_date AND :end_date
        ";

        $params = [
            ':start_date' => $start_date,
            ':end_date' => $end_date
        ];

        if (!empty($customer_id)) {
            $sql .= " AND r.customer_id = :customer_id";
            $params[':customer_id'] = $customer_id;
        }

        if (!empty($status)) {
            $sql .= " AND r.status = :status";
            $params[':status'] = $status;
        }

        $sql .= " ORDER BY r.due_date ASC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $receivables = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 计算应收账款总额
        $sql = "SELECT 
            SUM(r.balance) AS total_balance,
            SUM(CASE WHEN r.status = 'overdue' THEN r.balance ELSE 0 END) AS overdue_balance
        FROM receivables r 
        WHERE r.invoice_date BETWEEN :start_date AND :end_date";

        $stmt = $pdo->prepare($sql);
        $stmt->execute([':start_date' => $start_date, ':end_date' => $end_date]);
        $receivableSummary = $stmt->fetch(PDO::FETCH_ASSOC);
        $total_receivable = $receivableSummary['total_balance'] ?? 0;
        $overdue_receivable = $receivableSummary['overdue_balance'] ?? 0;

        // 获取收款记录总额
        $stmt = $pdo->prepare("
            SELECT SUM(pr.amount) as total
            FROM payments_received pr
            WHERE pr.payment_date BETWEEN :start_date AND :end_date
        " . (!empty($customer_id) ? " AND pr.receivable_id IN (SELECT id FROM receivables WHERE customer_id = :customer_id)" : ""));

        $params = [':start_date' => $start_date, ':end_date' => $end_date];
        if (!empty($customer_id)) {
            $params[':customer_id'] = $customer_id;
        }

        $stmt->execute($params);
        $total_received = $stmt->fetchColumn() ?? 0;
    }

    // 获取应付账款数据
    if ($type == 'payables') {
        $sql = "
            SELECT 
                p.id,
                p.invoice_number,
                p.invoice_date,
                p.due_date,
                p.amount,
                p.paid_amount,
                p.balance,
                p.status,
                s.name AS supplier_name,
                po.order_number AS purchase_order_number
            FROM 
                payables p
            JOIN 
                suppliers s ON p.supplier_id = s.id
            JOIN 
                purchase_orders po ON p.purchase_order_id = po.id
            WHERE 
                p.invoice_date BETWEEN :start_date AND :end_date
        ";

        $params = [
            ':start_date' => $start_date,
            ':end_date' => $end_date
        ];

        if (!empty($supplier_id)) {
            $sql .= " AND p.supplier_id = :supplier_id";
            $params[':supplier_id'] = $supplier_id;
        }

        if (!empty($status)) {
            $sql .= " AND p.status = :status";
            $params[':status'] = $status;
        }

        $sql .= " ORDER BY p.due_date ASC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $payables = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    // 获取收款记录数据
    if ($type == 'payments_received') {
        $sql = "
            SELECT 
                pr.id,
                pr.receivable_id,
                pr.amount,
                pr.payment_date,
                pr.payment_method,
                pr.reference_number,
                pr.notes,
                r.invoice_number,
                c.name AS customer_name,
                so.order_number AS sales_order_number
            FROM 
                payments_received pr
            JOIN 
                receivables r ON pr.receivable_id = r.id
            JOIN 
                customers c ON r.customer_id = c.id
            JOIN 
                sales_orders so ON r.sales_order_id = so.id
            WHERE 
                pr.payment_date BETWEEN :start_date AND :end_date
        ";

        $params = [
            ':start_date' => $start_date,
            ':end_date' => $end_date
        ];

        if (!empty($customer_id)) {
            $sql .= " AND r.customer_id = :customer_id";
            $params[':customer_id'] = $customer_id;
        }

        $sql .= " ORDER BY pr.payment_date DESC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $payments_received = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 计算收款总额
        $total_received = 0;
        foreach ($payments_received as $payment) {
            $total_received += $payment['amount'];
        }
    }

    // 获取付款记录数据
    if ($type == 'payments_made') {
        $sql = "
            SELECT 
                pm.id,
                pm.payable_id,
                pm.amount,
                pm.payment_date,
                pm.payment_method,
                pm.reference_number,
                pm.notes,
                p.invoice_number,
                s.name AS supplier_name,
                po.order_number AS purchase_order_number
            FROM 
                payments_made pm
            JOIN 
                payables p ON pm.payable_id = p.id
            JOIN 
                suppliers s ON p.supplier_id = s.id
            JOIN 
                purchase_orders po ON p.purchase_order_id = po.id
            WHERE 
                pm.payment_date BETWEEN :start_date AND :end_date
        ";

        $params = [
            ':start_date' => $start_date,
            ':end_date' => $end_date
        ];

        if (!empty($supplier_id)) {
            $sql .= " AND p.supplier_id = :supplier_id";
            $params[':supplier_id'] = $supplier_id;
        }

        $sql .= " ORDER BY pm.payment_date DESC";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $payments_made = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 计算付款总额
        $total_paid_out = 0;
        foreach ($payments_made as $payment) {
            $total_paid_out += $payment['amount'];
        }
    }
} catch (Exception $e) {
    $error = "查询数据时出错: " . $e->getMessage();
}

try {
    // 添加外键约束（在所有表都创建后）
    // 检查表和字段类型
    $stmt = $pdo->query("DESCRIBE sales_orders id");
    $sales_order_id_type = $stmt->fetch(PDO::FETCH_ASSOC)['Type'];

    $stmt = $pdo->query("DESCRIBE customers id");
    $customer_id_type = $stmt->fetch(PDO::FETCH_ASSOC)['Type'];

    $stmt = $pdo->query("DESCRIBE purchase_orders id");
    $purchase_order_id_type = $stmt->fetch(PDO::FETCH_ASSOC)['Type'];

    $stmt = $pdo->query("DESCRIBE suppliers id");
    $supplier_id_type = $stmt->fetch(PDO::FETCH_ASSOC)['Type'];

    // 添加receivables的外键
    $pdo->exec("ALTER TABLE `receivables` ADD CONSTRAINT `fk_receivables_sales_orders` 
                FOREIGN KEY (`sales_order_id`) REFERENCES `sales_orders` (`id`) ON DELETE CASCADE");

    $pdo->exec("ALTER TABLE `receivables` ADD CONSTRAINT `fk_receivables_customers`
                FOREIGN KEY (`customer_id`) REFERENCES `customers` (`id`) ON DELETE CASCADE");

    // 添加payables的外键
    $pdo->exec("ALTER TABLE `payables` ADD CONSTRAINT `fk_payables_purchase_orders` 
                FOREIGN KEY (`purchase_order_id`) REFERENCES `purchase_orders` (`id`) ON DELETE CASCADE");

    $pdo->exec("ALTER TABLE `payables` ADD CONSTRAINT `fk_payables_suppliers`
                FOREIGN KEY (`supplier_id`) REFERENCES `suppliers` (`id`) ON DELETE CASCADE");

    // 添加payments_received的外键
    $pdo->exec("ALTER TABLE `payments_received` ADD CONSTRAINT `fk_payments_received_receivables` 
                FOREIGN KEY (`receivable_id`) REFERENCES `receivables` (`id`) ON DELETE CASCADE");

    // 添加payments_made的外键
    $pdo->exec("ALTER TABLE `payments_made` ADD CONSTRAINT `fk_payments_made_payables` 
                FOREIGN KEY (`payable_id`) REFERENCES `payables` (`id`) ON DELETE CASCADE");
} catch (Exception $e) {
    // 仅记录错误，不要中断程序
    error_log("添加外键约束失败: " . $e->getMessage());
}

// 计算应付账款总额
$sql = "SELECT 
    SUM(p.balance) AS total_balance,
    SUM(CASE WHEN p.status = 'overdue' THEN p.balance ELSE 0 END) AS overdue_balance
FROM payables p 
WHERE p.invoice_date BETWEEN :start_date AND :end_date";

$stmt = $pdo->prepare($sql);
$stmt->execute([':start_date' => $start_date, ':end_date' => $end_date]);
$payableSummary = $stmt->fetch(PDO::FETCH_ASSOC);
$total_payable = $payableSummary['total_balance'] ?? 0;
$overdue_payable = $payableSummary['overdue_balance'] ?? 0;

// 计算付款总额
$stmt = $pdo->prepare("
    SELECT SUM(pm.amount) as total
    FROM payments_made pm
    WHERE pm.payment_date BETWEEN :start_date AND :end_date
" . (!empty($supplier_id) ? " AND pm.payable_id IN (SELECT id FROM payables WHERE supplier_id = :supplier_id)" : ""));

$params = [':start_date' => $start_date, ':end_date' => $end_date];
if (!empty($supplier_id)) {
    $params[':supplier_id'] = $supplier_id;
}

$stmt->execute($params);
$total_paid = $stmt->fetchColumn() ?? 0;
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>应收应付管理 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .dashboard-card {
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
            box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .receivable-card {
            background-color: #e3f2fd;
        }

        .payable-card {
            background-color: #ffebee;
        }

        .received-card {
            background-color: #e8f5e9;
        }

        .paid-card {
            background-color: #fff8e1;
        }

        .overdue-card {
            background-color: #ffcdd2;
        }

        .card-title {
            font-size: 16px;
            font-weight: bold;
            margin-bottom: 10px;
        }

        .card-value {
            font-size: 24px;
            font-weight: bold;
        }

        .filter-section {
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
            margin-bottom: 20px;
        }

        .tab-navigation {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-button {
            padding: 10px 20px;
            background: none;
            border: none;
            cursor: pointer;
            font-size: 16px;
            font-weight: bold;
            color: #6c757d;
        }

        .tab-button.active {
            border-bottom: 3px solid #0d6efd;
            color: #0d6efd;
        }

        .status-badge {
            display: inline-block;
            padding: 3px 6px;
            border-radius: 4px;
            font-size: 12px;
            color: white;
            white-space: nowrap;
            min-width: 60px;
            text-align: center;
        }

        .status-pending {
            background-color: #6c757d;
        }

        .status-partial {
            background-color: #fd7e14;
        }

        .status-paid {
            background-color: #28a745;
        }

        .status-overdue {
            background-color: #dc3545;
        }

        /* 表格和行样式 */
        .table-container {
            overflow-x: auto;
        }

        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        table th,
        table td {
            padding: 10px 8px;
            border: 1px solid #ddd;
            text-align: left;
        }

        table th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        tr.overdue {
            background-color: #ffe6e6 !important;
        }

        .action-buttons {
            display: flex;
            gap: 3px;
            white-space: nowrap;
        }

        .btn-pay,
        .btn-view {
            padding: 3px 6px;
            font-size: 12px;
            min-width: 40px;
            text-align: center;
        }

        .btn-pay {
            background-color: #28a745;
        }

        .btn-view {
            background-color: #17a2b8;
        }

        /* 模态框样式 */
        .modal {
            display: none;
            position: fixed;
            z-index: 1000;
            left: 0;
            top: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5);
            overflow-y: auto;
        }

        .modal-content {
            background-color: white;
            margin: 5% auto;
            padding: 20px;
            border-radius: 8px;
            max-width: 600px;
            max-height: 80vh;
            overflow-y: auto;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.2);
        }

        .modal-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .modal-title {
            font-size: 20px;
            font-weight: bold;
        }

        .close-button {
            font-size: 24px;
            cursor: pointer;
        }

        /* 表单样式 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }

        .form-control {
            width: 100%;
            padding: 8px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            box-sizing: border-box;
        }

        /* 网格系统 */
        .row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -15px;
            margin-left: -15px;
        }

        .col-md-3 {
            flex: 0 0 25%;
            max-width: 25%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-md-4 {
            flex: 0 0 33.33%;
            max-width: 33.33%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-md-6 {
            flex: 0 0 50%;
            max-width: 50%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        .col-md-12 {
            flex: 0 0 100%;
            max-width: 100%;
            padding-right: 15px;
            padding-left: 15px;
            box-sizing: border-box;
        }

        /* 按钮样式 */
        .btn {
            display: inline-block;
            padding: 5px 10px;
            margin: 2px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 13px;
            text-decoration: none;
        }

        .btn:hover {
            background-color: #2980b9;
        }

        .btn-outline-secondary {
            background-color: transparent;
            border: 1px solid #6c757d;
            color: #6c757d;
        }

        .btn-outline-secondary:hover {
            background-color: #6c757d;
            color: white;
        }

        .btn-primary {
            background-color: #0d6efd;
        }

        .btn-primary:hover {
            background-color: #0a58ca;
        }

        /* 卡片和容器 */
        .container {
            width: 100%;
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        .card {
            position: relative;
            display: flex;
            flex-direction: column;
            min-width: 0;
            word-wrap: break-word;
            background-color: #fff;
            background-clip: border-box;
            border: 1px solid rgba(0, 0, 0, .125);
            border-radius: 8px;
            margin-bottom: 20px;
            box-shadow: 0 2px 4px rgba(0, 0, 0, .1);
        }

        .card-header {
            padding: 12px 20px;
            margin-bottom: 0;
            background-color: rgba(0, 0, 0, .03);
            border-bottom: 1px solid rgba(0, 0, 0, .125);
        }

        .card-body {
            flex: 1 1 auto;
            padding: 20px;
        }

        /* 消息提示样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            border: 1px solid transparent;
        }

        .alert-success {
            background-color: #d4edda;
            border-color: #c3e6cb;
            color: #155724;
        }

        .alert-danger {
            background-color: #f8d7da;
            border-color: #f5c6cb;
            color: #721c24;
        }

        /* 表格列宽调整 */
        table th:nth-child(8),
        /* 剩余金额列 */
        table td:nth-child(8) {
            width: 90px;
        }

        table th:nth-child(9),
        /* 状态列 */
        table td:nth-child(9) {
            width: 80px;
        }

        table th:last-child,
        /* 操作列 */
        table td:last-child {
            width: 90px;
        }

        /* 响应式调整 */
        @media (max-width: 768px) {

            .col-md-3,
            .col-md-4,
            .col-md-6 {
                flex: 0 0 100%;
                max-width: 100%;
            }

            .dashboard-card {
                margin-bottom: 10px;
            }

            .tab-button {
                padding: 8px 12px;
                font-size: 14px;
            }
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>应收应付管理</h1>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger">
                <?php echo $_SESSION['error']; ?>
                <?php unset($_SESSION['error']); ?>
            </div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success">
                <?php echo $_SESSION['success']; ?>
                <?php unset($_SESSION['success']); ?>
            </div>
        <?php endif; ?>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php endif; ?>

        <?php if (empty($error)): ?>
            <!-- 选项卡导航 -->
            <div class="tab-navigation">
                <button class="tab-button <?php echo $type == 'receivables' ? 'active' : ''; ?>"
                    onclick="window.location.href='?type=receivables'">应收账款</button>
                <button class="tab-button <?php echo $type == 'payables' ? 'active' : ''; ?>"
                    onclick="window.location.href='?type=payables'">应付账款</button>
                <button class="tab-button <?php echo $type == 'payments_received' ? 'active' : ''; ?>"
                    onclick="window.location.href='?type=payments_received'">收款记录</button>
                <button class="tab-button <?php echo $type == 'payments_made' ? 'active' : ''; ?>"
                    onclick="window.location.href='?type=payments_made'">付款记录</button>
            </div>

            <!-- 筛选表单 -->
            <div class="filter-section">
                <form method="GET" class="row">
                    <input type="hidden" name="type" value="<?php echo $type; ?>">

                    <div class="col-md-3">
                        <label for="start_date" class="form-label">开始日期</label>
                        <input type="date" class="form-control" id="start_date" name="start_date" value="<?php echo $start_date; ?>">
                    </div>

                    <div class="col-md-3">
                        <label for="end_date" class="form-label">结束日期</label>
                        <input type="date" class="form-control" id="end_date" name="end_date" value="<?php echo $end_date; ?>">
                    </div>

                    <?php if ($type == 'receivables' || $type == 'payments_received'): ?>
                        <div class="col-md-3">
                            <label for="customer_id" class="form-label">客户</label>
                            <select class="form-control" id="customer_id" name="customer_id">
                                <option value="">所有客户</option>
                                <?php foreach ($customers as $customer): ?>
                                    <option value="<?php echo $customer['id']; ?>"
                                        <?php echo ($customer['id'] == $customer_id) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($customer['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    <?php endif; ?>

                    <?php if ($type == 'payables' || $type == 'payments_made'): ?>
                        <div class="col-md-3">
                            <label for="supplier_id" class="form-label">供应商</label>
                            <select class="form-control" id="supplier_id" name="supplier_id">
                                <option value="">所有供应商</option>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?php echo $supplier['id']; ?>"
                                        <?php echo ($supplier['id'] == $supplier_id) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($supplier['name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    <?php endif; ?>

                    <?php if ($type == 'receivables' || $type == 'payables'): ?>
                        <div class="col-md-3">
                            <label for="status" class="form-label">状态</label>
                            <select class="form-control" id="status" name="status">
                                <option value="">所有状态</option>
                                <option value="pending" <?php echo ($status == 'pending') ? 'selected' : ''; ?>>待付款</option>
                                <option value="partial" <?php echo ($status == 'partial') ? 'selected' : ''; ?>>部分付款</option>
                                <option value="paid" <?php echo ($status == 'paid') ? 'selected' : ''; ?>>已付款</option>
                                <option value="overdue" <?php echo ($status == 'overdue') ? 'selected' : ''; ?>>逾期</option>
                            </select>
                        </div>
                    <?php endif; ?>

                    <div class="col-md-12" style="margin-top: 10px;">
                        <button type="submit" class="btn btn-primary">应用筛选</button>
                        <a href="?type=<?php echo $type; ?>" class="btn btn-outline-secondary">重置</a>
                    </div>
                </form>
            </div>

            <!-- 显示应收账款 -->
            <?php if ($type == 'receivables'): ?>
                <!-- 应收账款统计 -->
                <div class="row">
                    <div class="col-md-4">
                        <div class="dashboard-card receivable-card">
                            <div class="card-title">应收账款总额</div>
                            <div class="card-value">¥<?php echo number_format($total_receivable, 2); ?></div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="dashboard-card received-card">
                            <div class="card-title">已收款总额</div>
                            <div class="card-value">¥<?php echo number_format($total_received, 2); ?></div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="dashboard-card overdue-card">
                            <div class="card-title">逾期应收账款</div>
                            <div class="card-value">¥<?php echo number_format($overdue_receivable, 2); ?></div>
                        </div>
                    </div>
                </div>

                <!-- 应收账款列表 -->
                <div class="card">
                    <div class="card-header">
                        <h3>应收账款列表</h3>
                    </div>
                    <div class="card-body">
                        <div class="table-container">
                            <table>
                                <thead>
                                    <tr>
                                        <th>发票号</th>
                                        <th>客户名称</th>
                                        <th>订单号</th>
                                        <th>发票日期</th>
                                        <th>到期日期</th>
                                        <th>金额</th>
                                        <th>已付金额</th>
                                        <th>剩余金额</th>
                                        <th>状态</th>
                                        <th>操作</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($receivables)): ?>
                                        <tr>
                                            <td colspan="10" style="text-align: center;">没有找到符合条件的应收账款记录</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($receivables as $receivable): ?>
                                            <tr class="<?php echo $receivable['status'] == 'overdue' ? 'overdue' : ''; ?>">
                                                <td><?php echo htmlspecialchars($receivable['invoice_number']); ?></td>
                                                <td><?php echo htmlspecialchars($receivable['customer_name']); ?></td>
                                                <td><?php echo htmlspecialchars($receivable['sales_order_number']); ?></td>
                                                <td><?php echo date('Y-m-d', strtotime($receivable['invoice_date'])); ?></td>
                                                <td><?php echo date('Y-m-d', strtotime($receivable['due_date'])); ?></td>
                                                <td>¥<?php echo number_format($receivable['amount'], 2); ?></td>
                                                <td>¥<?php echo number_format($receivable['paid_amount'], 2); ?></td>
                                                <td>¥<?php echo number_format($receivable['balance'], 2); ?></td>
                                                <td>
                                                    <span class="status-badge status-<?php echo $receivable['status']; ?>">
                                                        <?php
                                                        switch ($receivable['status']) {
                                                            case 'pending':
                                                                echo '待付款';
                                                                break;
                                                            case 'partial':
                                                                echo '部分付款';
                                                                break;
                                                            case 'paid':
                                                                echo '已付款';
                                                                break;
                                                            case 'overdue':
                                                                echo '逾期';
                                                                break;
                                                            default:
                                                                echo $receivable['status'];
                                                        }
                                                        ?>
                                                    </span>
                                                </td>
                                                <td>
                                                    <div class="action-buttons">
                                                        <?php if ($receivable['status'] != 'paid'): ?>
                                                            <button class="btn btn-pay"
                                                                onclick="showReceivePaymentModal(<?php echo $receivable['id']; ?>, '<?php echo htmlspecialchars($receivable['invoice_number']); ?>', <?php echo $receivable['balance']; ?>)">
                                                                收款
                                                            </button>
                                                        <?php endif; ?>
                                                        <button class="btn btn-view"
                                                            onclick="viewPaymentHistory(<?php echo $receivable['id']; ?>, 'receivable')">
                                                            查看
                                                        </button>
                                                    </div>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>

                <!-- 收款模态框 -->
                <div id="receivePaymentModal" class="modal">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h3 class="modal-title">记录收款</h3>
                            <span class="close-button" onclick="closeModal('receivePaymentModal')">&times;</span>
                        </div>
                        <form id="receivePaymentForm" method="POST" action="payment_process.php">
                            <input type="hidden" name="csrf_token" value="<?php echo $_SESSION['csrf_token'] ?? ''; ?>">
                            <input type="hidden" name="action" value="receive_payment">
                            <input type="hidden" name="receivable_id" id="receivable_id">

                            <div class="form-group">
                                <label class="form-label">发票号</label>
                                <input type="text" class="form-control" id="invoice_number_display" readonly>
                            </div>

                            <div class="form-group">
                                <label class="form-label">剩余应收金额</label>
                                <input type="text" class="form-control" id="balance_display" readonly>
                            </div>

                            <div class="form-group">
                                <label for="payment_amount" class="form-label">收款金额</label>
                                <input type="number" class="form-control" id="payment_amount" name="payment_amount" step="0.01" required>
                            </div>

                            <div class="form-group">
                                <label for="payment_date" class="form-label">收款日期</label>
                                <input type="date" class="form-control" id="payment_date" name="payment_date" value="<?php echo date('Y-m-d'); ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="payment_method" class="form-label">付款方式</label>
                                <select class="form-control" id="payment_method" name="payment_method" required>
                                    <option value="bank_transfer">银行转账</option>
                                    <option value="cash">现金</option>
                                    <option value="check">支票</option>
                                    <option value="credit_card">信用卡</option>
                                    <option value="other">其他</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="reference_number" class="form-label">参考编号</label>
                                <input type="text" class="form-control" id="reference_number" name="reference_number">
                            </div>

                            <div class="form-group">
                                <label for="notes" class="form-label">备注</label>
                                <textarea class="form-control" id="notes" name="notes" rows="3"></textarea>
                            </div>

                            <button type="submit" class="btn btn-primary">提交</button>
                            <button type="button" class="btn btn-outline-secondary" onclick="closeModal('receivePaymentModal')">取消</button>
                        </form>
                    </div>
                </div>
            <?php elseif ($type == 'payments_received'): ?>
                <!-- 收款记录列表 -->
                <div class="card">
                    <div class="card-header">
                        <h3>收款记录列表</h3>
                    </div>
                    <div class="card-body">
                        <div class="dashboard-card received-card" style="margin-bottom: 20px;">
                            <div class="card-title">收款总额</div>
                            <div class="card-value">¥<?php echo number_format($total_received, 2); ?></div>
                        </div>

                        <div class="table-container">
                            <table>
                                <thead>
                                    <tr>
                                        <th>收款日期</th>
                                        <th>发票号</th>
                                        <th>客户名称</th>
                                        <th>订单号</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>参考编号</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($payments_received)): ?>
                                        <tr>
                                            <td colspan="8" style="text-align: center;">没有找到符合条件的收款记录</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($payments_received as $payment): ?>
                                            <tr>
                                                <td><?php echo date('Y-m-d', strtotime($payment['payment_date'])); ?></td>
                                                <td><?php echo htmlspecialchars($payment['invoice_number']); ?></td>
                                                <td><?php echo htmlspecialchars($payment['customer_name']); ?></td>
                                                <td><?php echo htmlspecialchars($payment['sales_order_number']); ?></td>
                                                <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                                <td>
                                                    <?php
                                                    switch ($payment['payment_method']) {
                                                        case 'bank_transfer':
                                                            echo '银行转账';
                                                            break;
                                                        case 'cash':
                                                            echo '现金';
                                                            break;
                                                        case 'check':
                                                            echo '支票';
                                                            break;
                                                        case 'credit_card':
                                                            echo '信用卡';
                                                            break;
                                                        case 'other':
                                                            echo '其他';
                                                            break;
                                                        default:
                                                            echo $payment['payment_method'];
                                                    }
                                                    ?>
                                                </td>
                                                <td><?php echo htmlspecialchars($payment['reference_number'] ?? '-'); ?></td>
                                                <td><?php echo htmlspecialchars($payment['notes'] ?? '-'); ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            <?php elseif ($type == 'payments_made'): ?>
                <!-- 付款记录列表 -->
                <div class="card">
                    <div class="card-header">
                        <h3>付款记录列表</h3>
                    </div>
                    <div class="card-body">
                        <div class="dashboard-card paid-card" style="margin-bottom: 20px;">
                            <div class="card-title">付款总额</div>
                            <div class="card-value">¥<?php echo number_format($total_paid_out, 2); ?></div>
                        </div>

                        <div class="table-container">
                            <table>
                                <thead>
                                    <tr>
                                        <th>付款日期</th>
                                        <th>发票号</th>
                                        <th>供应商名称</th>
                                        <th>采购单号</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>参考编号</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($payments_made)): ?>
                                        <tr>
                                            <td colspan="8" style="text-align: center;">没有找到符合条件的付款记录</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($payments_made as $payment): ?>
                                            <tr>
                                                <td><?php echo date('Y-m-d', strtotime($payment['payment_date'])); ?></td>
                                                <td><?php echo htmlspecialchars($payment['invoice_number']); ?></td>
                                                <td><?php echo htmlspecialchars($payment['supplier_name']); ?></td>
                                                <td><?php echo htmlspecialchars($payment['purchase_order_number']); ?></td>
                                                <td>¥<?php echo number_format($payment['amount'], 2); ?></td>
                                                <td>
                                                    <?php
                                                    switch ($payment['payment_method']) {
                                                        case 'bank_transfer':
                                                            echo '银行转账';
                                                            break;
                                                        case 'cash':
                                                            echo '现金';
                                                            break;
                                                        case 'check':
                                                            echo '支票';
                                                            break;
                                                        case 'credit_card':
                                                            echo '信用卡';
                                                            break;
                                                        case 'other':
                                                            echo '其他';
                                                            break;
                                                        default:
                                                            echo $payment['payment_method'];
                                                    }
                                                    ?>
                                                </td>
                                                <td><?php echo htmlspecialchars($payment['reference_number'] ?? '-'); ?></td>
                                                <td><?php echo htmlspecialchars($payment['notes'] ?? '-'); ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            <?php endif; ?>

            <!-- 查看支付历史模态框 -->
            <div id="paymentHistoryModal" class="modal">
                <div class="modal-content">
                    <div class="modal-header">
                        <h3 class="modal-title">支付历史记录</h3>
                        <span class="close-button" onclick="closeModal('paymentHistoryModal')">&times;</span>
                    </div>
                    <div id="paymentHistoryContent">
                        <!-- 支付历史记录将通过AJAX加载到这里 -->
                        <div class="table-container">
                            <table id="paymentHistoryTable">
                                <thead>
                                    <tr>
                                        <th>支付日期</th>
                                        <th>金额</th>
                                        <th>支付方式</th>
                                        <th>参考编号</th>
                                        <th>备注</th>
                                    </tr>
                                </thead>
                                <tbody id="paymentHistoryTableBody">
                                    <!-- 数据将通过JavaScript动态加载 -->
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>

            <!-- 显示应付账款 -->
        <?php elseif ($type == 'payables'): ?>
            <!-- 应付账款统计 -->
            <div class="row">
                <div class="col-md-4">
                    <div class="dashboard-card payable-card">
                        <div class="card-title">应付账款总额</div>
                        <div class="card-value">¥<?php echo number_format($total_payable, 2); ?></div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="dashboard-card paid-card">
                        <div class="card-title">已付款总额</div>
                        <div class="card-value">¥<?php echo number_format($total_paid, 2); ?></div>
                    </div>
                </div>
                <div class="col-md-4">
                    <div class="dashboard-card overdue-card">
                        <div class="card-title">逾期应付账款</div>
                        <div class="card-value">¥<?php echo number_format($overdue_payable, 2); ?></div>
                    </div>
                </div>
            </div>

            <!-- 应付账款列表 -->
            <div class="card">
                <div class="card-header">
                    <h3>应付账款列表</h3>
                </div>
                <div class="card-body">
                    <div class="table-container">
                        <table>
                            <thead>
                                <tr>
                                    <th>发票号</th>
                                    <th>供应商名称</th>
                                    <th>采购单号</th>
                                    <th>发票日期</th>
                                    <th>到期日期</th>
                                    <th>金额</th>
                                    <th>已付金额</th>
                                    <th>剩余金额</th>
                                    <th>状态</th>
                                    <th>操作</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php if (empty($payables)): ?>
                                    <tr>
                                        <td colspan="10" style="text-align: center;">没有找到符合条件的应付账款记录</td>
                                    </tr>
                                <?php else: ?>
                                    <?php foreach ($payables as $payable): ?>
                                        <tr class="<?php echo $payable['status'] == 'overdue' ? 'overdue' : ''; ?>">
                                            <td><?php echo htmlspecialchars($payable['invoice_number']); ?></td>
                                            <td><?php echo htmlspecialchars($payable['supplier_name']); ?></td>
                                            <td><?php echo htmlspecialchars($payable['purchase_order_number']); ?></td>
                                            <td><?php echo date('Y-m-d', strtotime($payable['invoice_date'])); ?></td>
                                            <td><?php echo date('Y-m-d', strtotime($payable['due_date'])); ?></td>
                                            <td>¥<?php echo number_format($payable['amount'], 2); ?></td>
                                            <td>¥<?php echo number_format($payable['paid_amount'], 2); ?></td>
                                            <td>¥<?php echo number_format($payable['balance'], 2); ?></td>
                                            <td>
                                                <span class="status-badge status-<?php echo $payable['status']; ?>">
                                                    <?php
                                                    switch ($payable['status']) {
                                                        case 'pending':
                                                            echo '待付款';
                                                            break;
                                                        case 'partial':
                                                            echo '部分付款';
                                                            break;
                                                        case 'paid':
                                                            echo '已付款';
                                                            break;
                                                        case 'overdue':
                                                            echo '逾期';
                                                            break;
                                                        default:
                                                            echo $payable['status'];
                                                    }
                                                    ?>
                                                </span>
                                            </td>
                                            <td>
                                                <div class="action-buttons">
                                                    <?php if ($payable['status'] != 'paid'): ?>
                                                        <button class="btn btn-pay"
                                                            onclick="showMakePaymentModal(<?php echo $payable['id']; ?>, '<?php echo htmlspecialchars($payable['invoice_number']); ?>', <?php echo $payable['balance']; ?>)">
                                                            付款
                                                        </button>
                                                    <?php endif; ?>
                                                    <button class="btn btn-view"
                                                        onclick="viewPaymentHistory(<?php echo $payable['id']; ?>, 'payable')">
                                                        查看
                                                    </button>
                                                </div>
                                            </td>
                                        </tr>
                                    <?php endforeach; ?>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- 付款模态框 -->
            <div id="makePaymentModal" class="modal">
                <div class="modal-content">
                    <div class="modal-header">
                        <h3 class="modal-title">记录付款</h3>
                        <span class="close-button" onclick="closeModal('makePaymentModal')">&times;</span>
                    </div>
                    <form id="makePaymentForm" method="POST" action="payment_process.php">
                        <input type="hidden" name="csrf_token" value="<?php echo $_SESSION['csrf_token'] ?? ''; ?>">
                        <input type="hidden" name="action" value="make_payment">
                        <input type="hidden" name="payable_id" id="payable_id">

                        <div class="form-group">
                            <label class="form-label">发票号</label>
                            <input type="text" class="form-control" id="payable_invoice_number" readonly>
                        </div>

                        <div class="form-group">
                            <label class="form-label">剩余应付金额</label>
                            <input type="text" class="form-control" id="payable_balance" readonly>
                        </div>

                        <div class="form-group">
                            <label for="payable_payment_amount" class="form-label">付款金额</label>
                            <input type="number" class="form-control" id="payable_payment_amount" name="payment_amount" step="0.01" required>
                        </div>

                        <div class="form-group">
                            <label for="payable_payment_date" class="form-label">付款日期</label>
                            <input type="date" class="form-control" id="payable_payment_date" name="payment_date" value="<?php echo date('Y-m-d'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="payable_payment_method" class="form-label">付款方式</label>
                            <select class="form-control" id="payable_payment_method" name="payment_method" required>
                                <option value="bank_transfer">银行转账</option>
                                <option value="cash">现金</option>
                                <option value="check">支票</option>
                                <option value="credit_card">信用卡</option>
                                <option value="other">其他</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="payable_reference_number" class="form-label">参考编号</label>
                            <input type="text" class="form-control" id="payable_reference_number" name="reference_number">
                        </div>

                        <div class="form-group">
                            <label for="payable_notes" class="form-label">备注</label>
                            <textarea class="form-control" id="payable_notes" name="notes" rows="3"></textarea>
                        </div>

                        <button type="submit" class="btn btn-primary">提交</button>
                        <button type="button" class="btn btn-outline-secondary" onclick="closeModal('makePaymentModal')">取消</button>
                    </form>
                </div>
            </div>
        <?php endif; ?>

    </div>

    <script>
        // 显示收款模态框
        function showReceivePaymentModal(receivableId, invoiceNumber, balance) {
            document.getElementById('receivable_id').value = receivableId;
            document.getElementById('invoice_number_display').value = invoiceNumber;
            document.getElementById('balance_display').value = '¥' + balance.toFixed(2);
            document.getElementById('payment_amount').max = balance;
            document.getElementById('payment_amount').value = balance;
            document.getElementById('receivePaymentModal').style.display = 'block';
        }

        // 显示付款模态框
        function showMakePaymentModal(payableId, invoiceNumber, balance) {
            document.getElementById('payable_id').value = payableId;
            document.getElementById('payable_invoice_number').value = invoiceNumber;
            document.getElementById('payable_balance').value = '¥' + balance.toFixed(2);
            document.getElementById('payable_payment_amount').max = balance;
            document.getElementById('payable_payment_amount').value = balance;
            document.getElementById('makePaymentModal').style.display = 'block';
        }

        // 查看付款历史记录
        function viewPaymentHistory(id, type) {
            // 在模态框中显示加载中
            document.getElementById('paymentHistoryTableBody').innerHTML = '<tr><td colspan="5" style="text-align:center">加载中...</td></tr>';
            document.getElementById('paymentHistoryModal').style.display = 'block';

            // 使用AJAX加载付款历史
            var xhr = new XMLHttpRequest();
            xhr.open('GET', 'payment_history_ajax.php?' + type + '_id=' + id, true);
            xhr.onload = function() {
                if (this.status == 200) {
                    try {
                        var payments = JSON.parse(this.responseText);
                        var html = '';

                        if (payments.length === 0) {
                            html = '<tr><td colspan="5" style="text-align:center">暂无支付记录</td></tr>';
                        } else {
                            for (var i = 0; i < payments.length; i++) {
                                var payment = payments[i];
                                html += '<tr>' +
                                    '<td>' + payment.payment_date + '</td>' +
                                    '<td>¥' + parseFloat(payment.amount).toFixed(2) + '</td>' +
                                    '<td>' + getPaymentMethodText(payment.payment_method) + '</td>' +
                                    '<td>' + (payment.reference_number || '-') + '</td>' +
                                    '<td>' + (payment.notes || '-') + '</td>' +
                                    '</tr>';
                            }
                        }

                        document.getElementById('paymentHistoryTableBody').innerHTML = html;
                    } catch (e) {
                        document.getElementById('paymentHistoryTableBody').innerHTML =
                            '<tr><td colspan="5" style="text-align:center">加载失败，请稍后再试</td></tr>';
                        console.error('解析响应失败:', e);
                    }
                } else {
                    document.getElementById('paymentHistoryTableBody').innerHTML =
                        '<tr><td colspan="5" style="text-align:center">加载失败，请稍后再试</td></tr>';
                }
            };
            xhr.onerror = function() {
                document.getElementById('paymentHistoryTableBody').innerHTML =
                    '<tr><td colspan="5" style="text-align:center">网络错误，请检查连接</td></tr>';
            };
            xhr.send();
        }

        // 支付方式文本映射
        function getPaymentMethodText(method) {
            var methodMap = {
                'bank_transfer': '银行转账',
                'cash': '现金',
                'check': '支票',
                'credit_card': '信用卡',
                'other': '其他'
            };
            return methodMap[method] || method;
        }

        // 关闭模态框
        function closeModal(modalId) {
            document.getElementById(modalId).style.display = 'none';
        }

        // 当用户点击模态框外部时关闭
        window.onclick = function(event) {
            if (event.target.className === 'modal') {
                event.target.style.display = 'none';
            }
        }
    </script>
</body>

</html>