<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取搜索参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$location_id = isset($_GET['location_id']) ? (int)$_GET['location_id'] : 0;
$low_stock_only = isset($_GET['low_stock_only']) ? (bool)$_GET['low_stock_only'] : false;
$batch_filter = isset($_GET['batch_filter']) ? trim($_GET['batch_filter']) : '';

// 获取所有仓库位置
try {
    $stmt = $pdo->query("
        SELECT id, name, type, temperature_controlled, humidity_controlled
        FROM storage_locations
        ORDER BY name
    ");
    $locations = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取仓库位置失败：" . $e->getMessage();
}

// 查询半成品库存
try {
    $query = "
        SELECT 
            i.id,
            p.id AS product_id,
            p.name AS product_name,
            p.specification,
            p.description,
            i.quantity_on_hand,
            i.unit,
            i.low_stock_threshold,
            sl.id AS location_id,
            sl.name AS location_name,
            sl.temperature_controlled,
            sl.humidity_controlled,
            i.last_updated,
            p.shelf_life_days
        FROM 
            inventory i
        JOIN 
            products p ON i.product_id = p.id
        JOIN 
            storage_locations sl ON i.storage_location_id = sl.id
        WHERE 
            p.type = 'semi-finished'
    ";

    $params = [];

    // 添加搜索条件
    if (!empty($search)) {
        $query .= " AND (p.name LIKE ? OR p.specification LIKE ? OR p.description LIKE ?)";
        $params[] = "%$search%";
        $params[] = "%$search%";
        $params[] = "%$search%";
    }

    // 按仓库位置筛选
    if ($location_id > 0) {
        $query .= " AND sl.id = ?";
        $params[] = $location_id;
    }

    // 只显示低库存
    if ($low_stock_only) {
        $query .= " AND i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0";
    }

    $query .= " ORDER BY (CASE WHEN i.quantity_on_hand <= i.low_stock_threshold AND i.low_stock_threshold > 0 THEN 0 ELSE 1 END), p.name";

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    $semiFinishedGoods = $stmt->fetchAll();

    // 对每个半成品获取最近的生产批次
    foreach ($semiFinishedGoods as &$product) {
        $batchQuery = "
            SELECT 
                pb.id, 
                pb.batch_number, 
                pb.start_time,
                pb.end_time,
                pb.status,
                pb.quantity_produced
            FROM 
                production_batches pb
            WHERE 
                pb.product_id = ? 
                AND pb.status IN ('completed', 'quality_check', 'stocked')
                " . (!empty($batch_filter) ? " AND pb.batch_number LIKE ?" : "") . "
            ORDER BY 
                pb.end_time DESC
            LIMIT 3
        ";

        $batchParams = [$product['product_id']];
        if (!empty($batch_filter)) {
            $batchParams[] = "%$batch_filter%";
        }

        $batchStmt = $pdo->prepare($batchQuery);
        $batchStmt->execute($batchParams);
        $product['recent_batches'] = $batchStmt->fetchAll();
    }
} catch (PDOException $e) {
    $error = "获取半成品库存失败：" . $e->getMessage();
}

// 批次状态对应的显示文本和样式
$batchStatusDisplay = [
    'planned' => ['text' => '计划中', 'class' => '待处理'],
    'in_progress' => ['text' => '生产中', 'class' => '进行中'],
    'completed' => ['text' => '已完成', 'class' => '已完成'],
    'quality_check' => ['text' => '质检中', 'class' => '进行中'],
    'stocked' => ['text' => '已入库', 'class' => '已完成'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>半成品库存管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .container {
            max-width: 1000px;
            margin: 50px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .low-stock {
            background-color: #fff3cd !important;
            color: #856404;
        }

        .search-container {
            display: flex;
            flex-wrap: wrap;
            align-items: center;
            gap: 15px;
            margin-bottom: 20px;
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 8px;
        }

        .search-container input,
        .search-container select {
            padding: 8px 12px;
            border: 1px solid #ced4da;
            border-radius: 4px;
            flex-grow: 1;
        }

        .search-container button {
            padding: 8px 16px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .search-container button:hover {
            background-color: #2980b9;
        }

        .checkbox-container {
            display: flex;
            align-items: center;
            gap: 5px;
        }

        .checkbox-container input[type="checkbox"] {
            width: auto;
            flex-grow: 0;
        }

        .batch-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 12px;
            margin-bottom: 10px;
            background-color: #fff;
        }

        .batch-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 8px;
        }

        .batch-number {
            font-weight: bold;
            font-size: 14px;
        }

        .batch-info {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 8px;
            font-size: 13px;
        }

        .storage-conditions {
            display: flex;
            gap: 8px;
            margin-top: 5px;
        }

        .condition-tag {
            display: inline-block;
            padding: 2px 6px;
            border-radius: 4px;
            font-size: 12px;
            background-color: #e9ecef;
            color: #495057;
        }

        .condition-tag.temperature {
            background-color: #d4edda;
            color: #155724;
        }

        .condition-tag.humidity {
            background-color: #cce5ff;
            color: #004085;
        }

        .condition-tag.shelf-life {
            background-color: #f8d7da;
            color: #721c24;
        }

        .batch-list {
            max-height: 0;
            overflow: hidden;
            transition: max-height 0.3s ease-out;
        }

        .batch-list.open {
            max-height: 500px;
        }

        .toggle-batches {
            cursor: pointer;
            color: #3498db;
            user-select: none;
        }

        .toggle-batches:hover {
            text-decoration: underline;
        }

        .toggle-icon {
            margin-left: 5px;
            transition: transform 0.3s;
        }

        .toggle-icon.open {
            transform: rotate(180deg);
        }

        .stock-status {
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            font-size: 0.9em;
            color: white;
        }

        .status-sufficient {
            background-color: #28a745;
        }

        .status-low {
            background-color: #ffc107;
            color: #212529;
        }

        .status-critical {
            background-color: #dc3545;
        }

        .product-description {
            font-size: 0.85em;
            color: #6c757d;
            margin-top: 5px;
            font-style: italic;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>半成品库存管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <!-- 搜索筛选 -->
        <div class="search-container">
            <form method="GET" action="semi_finished_goods_inventory.php">
                <input type="text" name="search" placeholder="搜索半成品名称或规格" value="<?= htmlspecialchars($search) ?>">

                <select name="location_id">
                    <option value="0">所有仓库位置</option>
                    <?php foreach ($locations as $loc): ?>
                        <option value="<?= $loc['id'] ?>" <?= $location_id == $loc['id'] ? 'selected' : '' ?>>
                            <?= htmlspecialchars($loc['name']) ?>
                            <?= $loc['temperature_controlled'] ? ' (温控)' : '' ?>
                            <?= $loc['humidity_controlled'] ? ' (湿控)' : '' ?>
                        </option>
                    <?php endforeach; ?>
                </select>

                <input type="text" name="batch_filter" placeholder="批次号筛选" value="<?= htmlspecialchars($batch_filter) ?>">

                <div class="checkbox-container">
                    <input type="checkbox" id="low_stock_only" name="low_stock_only" value="1" <?= $low_stock_only ? 'checked' : '' ?>>
                    <label for="low_stock_only">只显示低库存</label>
                </div>

                <button type="submit">筛选</button>
                <button type="button" onclick="window.location.href='semi_finished_goods_inventory.php'">重置</button>
            </form>
        </div>

        <!-- 半成品库存表格 -->
        <div class="table-container">
            <?php if (empty($semiFinishedGoods)): ?>
                <div class="empty-state">
                    <p>暂无半成品库存数据</p>
                </div>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>半成品名称</th>
                            <th>规格</th>
                            <th>库存数量</th>
                            <th>单位</th>
                            <th>存放位置</th>
                            <th>库存状态</th>
                            <th>存储要求</th>
                            <th>相关批次</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($semiFinishedGoods as $product): ?>
                            <?php
                            $isLowStock = false;
                            $stockStatus = '';
                            $stockStatusClass = '';

                            if ($product['low_stock_threshold'] > 0) {
                                if ($product['quantity_on_hand'] <= $product['low_stock_threshold'] * 0.5) {
                                    $isLowStock = true;
                                    $stockStatus = '库存紧张';
                                    $stockStatusClass = 'status-critical';
                                } elseif ($product['quantity_on_hand'] <= $product['low_stock_threshold']) {
                                    $isLowStock = true;
                                    $stockStatus = '库存不足';
                                    $stockStatusClass = 'status-low';
                                } else {
                                    $stockStatus = '库存充足';
                                    $stockStatusClass = 'status-sufficient';
                                }
                            } else {
                                $stockStatus = '未设置预警';
                                $stockStatusClass = '';
                            }

                            $hasBatches = !empty($product['recent_batches']);
                            ?>
                            <tr class="<?= $isLowStock ? 'low-stock' : '' ?>">
                                <td>
                                    <?= htmlspecialchars($product['product_name']) ?>
                                    <?php if (!empty($product['description'])): ?>
                                        <div class="product-description"><?= htmlspecialchars($product['description']) ?></div>
                                    <?php endif; ?>
                                </td>
                                <td><?= htmlspecialchars($product['specification'] ?? '-') ?></td>
                                <td><?= number_format($product['quantity_on_hand'], 2) ?></td>
                                <td><?= htmlspecialchars($product['unit']) ?></td>
                                <td>
                                    <?= htmlspecialchars($product['location_name']) ?>
                                </td>
                                <td>
                                    <span class="stock-status <?= $stockStatusClass ?>"><?= $stockStatus ?></span>
                                    <?php if ($product['low_stock_threshold'] > 0): ?>
                                        <br>
                                        <small>预警值: <?= $product['low_stock_threshold'] ?> <?= $product['unit'] ?></small>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <div class="storage-conditions">
                                        <?php if ($product['temperature_controlled']): ?>
                                            <span class="condition-tag temperature">温控</span>
                                        <?php endif; ?>
                                        <?php if ($product['humidity_controlled']): ?>
                                            <span class="condition-tag humidity">湿控</span>
                                        <?php endif; ?>
                                        <?php if ($product['shelf_life_days']): ?>
                                            <span class="condition-tag shelf-life">保质期<?= $product['shelf_life_days'] ?>天</span>
                                        <?php endif; ?>
                                    </div>
                                </td>
                                <td>
                                    <?php if ($hasBatches): ?>
                                        <div class="toggle-batches" onclick="toggleBatches(this, 'batch-list-<?= $product['product_id'] ?>')">
                                            查看最近批次 <span class="toggle-icon">▼</span>
                                        </div>
                                        <div id="batch-list-<?= $product['product_id'] ?>" class="batch-list">
                                            <?php foreach ($product['recent_batches'] as $batch): ?>
                                                <?php
                                                $batchStatus = $batchStatusDisplay[$batch['status']] ?? ['text' => $batch['status'], 'class' => ''];
                                                ?>
                                                <div class="batch-card">
                                                    <div class="batch-header">
                                                        <div class="batch-number"><?= htmlspecialchars($batch['batch_number']) ?></div>
                                                        <div class="status-tag <?= $batchStatus['class'] ?>"><?= $batchStatus['text'] ?></div>
                                                    </div>
                                                    <div class="batch-info">
                                                        <div>开始时间: <?= $batch['start_time'] ? date('Y-m-d', strtotime($batch['start_time'])) : '-' ?></div>
                                                        <div>完成时间: <?= $batch['end_time'] ? date('Y-m-d', strtotime($batch['end_time'])) : '-' ?></div>
                                                        <div>生产数量: <?= $batch['quantity_produced'] ? number_format($batch['quantity_produced'], 2) . ' ' . $product['unit'] : '-' ?></div>
                                                        <div>
                                                            <a href="../production/batch_detail.php?batch_id=<?= $batch['id'] ?>" class="btn-link">查看批次详情</a>
                                                        </div>
                                                    </div>
                                                </div>
                                            <?php endforeach; ?>
                                            <?php if (count($product['recent_batches']) == 3): ?>
                                                <div style="text-align: center; margin-top: 10px;">
                                                    <a href="../production/batch_management.php?product_id=<?= $product['product_id'] ?>" class="btn-link">查看更多批次</a>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                    <?php else: ?>
                                        <span class="text-muted">暂无批次记录</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="inventory_history.php?product_id=<?= $product['product_id'] ?>" class="btn-link">查看记录</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <script>
        function toggleBatches(element, batchListId) {
            const batchList = document.getElementById(batchListId);
            const toggleIcon = element.querySelector('.toggle-icon');

            batchList.classList.toggle('open');
            toggleIcon.classList.toggle('open');
        }
    </script>
</body>

</html>