<?php
session_start();
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取参数
$tracking_number = isset($_GET['tracking_number']) ? trim($_GET['tracking_number']) : '';
$carrier_name = isset($_GET['carrier']) ? trim($_GET['carrier']) : '';
$shipment_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

// 确定返回链接，根据是否有id参数判断来源
$referrer = isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '';
$return_url = 'shipment_management.php';
if (strpos($referrer, 'tracking_list.php') !== false || isset($_GET['from_list'])) {
    $return_url = 'tracking_list.php';
}

// 如果没有物流单号参数，重定向到物流追踪列表页面
if (empty($tracking_number)) {
    header("Location: tracking_list.php");
    exit;
}

// 初始化变量
$error = '';
$shipment_info = null;
$tracking_info = [];

// 参数验证
if (empty($tracking_number)) {
    $error = "缺少物流单号参数";
} else {
    try {
        // 构建更精确的SQL查询
        $sql = "
            SELECT 
                s.*,
                so.order_number,
                c.name AS customer_name,
                cr.name AS carrier_name,
                cr.service_type,
                CONCAT(c.address, ' ', c.region) AS delivery_address
            FROM 
                shipments s
            JOIN 
                sales_orders so ON s.sales_order_id = so.id
            LEFT JOIN 
                customers c ON so.customer_id = c.id
            LEFT JOIN 
                carriers cr ON s.carrier_id = cr.id
            WHERE 
                s.tracking_number = ?
        ";

        // 如果有传入ID，则优先使用ID查询
        $params = [$tracking_number];
        if ($shipment_id > 0) {
            $sql = "
                SELECT 
                    s.*,
                    so.order_number,
                    c.name AS customer_name,
                    cr.name AS carrier_name,
                    cr.service_type,
                    CONCAT(c.address, ' ', c.region) AS delivery_address
                FROM 
                    shipments s
                JOIN 
                    sales_orders so ON s.sales_order_id = so.id
                LEFT JOIN 
                    customers c ON so.customer_id = c.id
                LEFT JOIN 
                    carriers cr ON s.carrier_id = cr.id
                WHERE 
                    s.id = ?
            ";
            $params = [$shipment_id];
        } else if (!empty($carrier_name)) {
            // 如果没有ID但有物流公司名称，则添加物流公司条件
            $sql .= " AND cr.name = ?";
            $params[] = $carrier_name;
        }

        // 添加排序，确保获取最新的记录
        $sql .= " ORDER BY s.updated_at DESC, s.id DESC LIMIT 1";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $shipment_info = $stmt->fetch();

        // 记录日志，用于调试
        if ($shipment_info) {
            error_log("[物流追踪] 成功查询物流信息: {$tracking_number}, 订单号: {$shipment_info['order_number']}");
        } else {
            error_log("[物流追踪] 未找到物流信息: {$tracking_number}, 物流公司: {$carrier_name}, ID: {$shipment_id}");
        }

        if (!$shipment_info) {
            // 如果没有在数据库中找到，但有传入物流公司名称，则显示模拟数据
            if (!empty($carrier_name)) {
                $shipment_info = [
                    'tracking_number' => $tracking_number,
                    'carrier_name' => $carrier_name,
                    'status' => 'in_transit',
                    'shipment_date' => date('Y-m-d H:i:s', strtotime('-3 days')),
                    'estimated_delivery_date' => date('Y-m-d', strtotime('+2 days')),
                    'order_number' => '未知订单',
                    'customer_name' => '未知客户',
                    'delivery_address' => '未知地址'
                ];
                error_log("[物流追踪] 使用模拟数据: {$tracking_number}, 物流公司: {$carrier_name}");
            } else {
                $error = "未找到该物流单号的信息";
            }
        }

        // 如果找到发货单信息，生成模拟物流轨迹
        if ($shipment_info && empty($error)) {
            // 生成一些模拟的物流轨迹点
            $tracking_info = generateTrackingInfo($tracking_number, $shipment_info);
        }
    } catch (PDOException $e) {
        $error = "查询数据失败: " . $e->getMessage();
        error_log("[物流追踪] 查询失败: {$e->getMessage()}");
    }
}

/**
 * 根据物流单号和发货信息生成模拟的物流跟踪信息
 * 
 * @param string $tracking_number 物流单号
 * @param array $shipment_info 发货信息
 * @return array 物流跟踪节点
 */
function generateTrackingInfo($tracking_number, $shipment_info)
{
    $status = $shipment_info['status'] ?? 'in_transit';
    $shipment_date = $shipment_info['shipment_date'] ?? date('Y-m-d H:i:s', strtotime('-3 days'));
    $estimated_delivery = $shipment_info['estimated_delivery_date'] ?? date('Y-m-d', strtotime('+2 days'));
    $carrier = $shipment_info['carrier_name'] ?? '未知物流公司';

    // 初始化基础物流节点
    $tracking_nodes = [];

    // 发货节点（一定有）
    $tracking_nodes[] = [
        'time' => $shipment_date,
        'location' => '发货仓库',
        'status' => '已发货',
        'description' => "包裹已由{$carrier}揽收",
        'is_current' => $status == 'shipped'
    ];

    // 根据状态生成不同的物流节点
    if (in_array($status, ['in_transit', 'delivered'])) {
        // 转运节点
        $transit_date = date('Y-m-d H:i:s', strtotime($shipment_date . ' +1 day'));
        $tracking_nodes[] = [
            'time' => $transit_date,
            'location' => '区域转运中心',
            'status' => '运输中',
            'description' => "包裹已到达{$carrier}区域转运中心",
            'is_current' => $status == 'in_transit' && count($tracking_nodes) == 1
        ];

        // 添加1-3个随机的中转节点
        $transit_count = rand(1, 3);
        $last_time = strtotime($transit_date);

        for ($i = 0; $i < $transit_count; $i++) {
            $hours_add = rand(8, 20);
            $last_time += $hours_add * 3600; // 增加随机小时数

            $city_list = ['上海', '广州', '深圳', '北京', '南京', '杭州', '武汉', '成都', '西安'];
            $city = $city_list[array_rand($city_list)];

            $action_list = ['已到达', '正在发往', '转运中', '派送中'];
            $action = $action_list[array_rand($action_list)];

            $tracking_nodes[] = [
                'time' => date('Y-m-d H:i:s', $last_time),
                'location' => "{$city}转运中心",
                'status' => '运输中',
                'description' => "包裹{$action}{$city}转运中心",
                'is_current' => $status == 'in_transit' && $i == $transit_count - 1
            ];
        }

        // 如果已送达，添加送达节点
        if ($status == 'delivered') {
            $delivery_time = !empty($shipment_info['actual_delivery_date']) ?
                $shipment_info['actual_delivery_date'] :
                date('Y-m-d H:i:s', strtotime($estimated_delivery . ' 14:00:00'));

            $tracking_nodes[] = [
                'time' => $delivery_time,
                'location' => '收货地址',
                'status' => '已送达',
                'description' => "包裹已送达，签收人：" . substr($shipment_info['customer_name'] ?? '收件人', 0, 1) . '**',
                'is_current' => true
            ];
        }
    }

    // 如果物流异常，添加异常信息
    if ($status == 'failed') {
        $tracking_nodes[] = [
            'time' => date('Y-m-d H:i:s', strtotime($shipment_date . ' +1 day +5 hours')),
            'location' => '配送站点',
            'status' => '配送异常',
            'description' => "配送失败：地址不详细，无法联系收件人",
            'is_current' => true
        ];
    }

    // 按时间倒序排列节点
    usort($tracking_nodes, function ($a, $b) {
        return strtotime($b['time']) - strtotime($a['time']);
    });

    return $tracking_nodes;
}

// 物流状态映射
$status_map = [
    'pending' => '待处理',
    'ready_to_ship' => '待发货',
    'shipped' => '已发货',
    'in_transit' => '运输中',
    'delivered' => '已送达',
    'failed' => '发货失败',
    'cancelled' => '已取消'
];

// 获取当前状态中文名
$current_status_text = $shipment_info ? ($status_map[$shipment_info['status']] ?? $shipment_info['status']) : '';

// 计算预计送达剩余天数
$days_remaining = 0;
if ($shipment_info && !empty($shipment_info['estimated_delivery_date']) && $shipment_info['status'] != 'delivered') {
    $today = new DateTime();
    $delivery_date = new DateTime($shipment_info['estimated_delivery_date']);
    $days_remaining = $today->diff($delivery_date)->days;

    // 如果是负数，说明已经超过预计送达日期
    if ($delivery_date < $today) {
        $days_remaining = -$days_remaining;
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>物流追踪 - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 追踪页面样式 */
        body {
            background-color: #f8f9fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .content {
            max-width: 900px;
            margin: 20px auto;
            padding: 20px;
        }

        .tracking-header {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            padding: 20px;
            margin-bottom: 20px;
            position: relative;
        }

        .tracking-status {
            display: flex;
            align-items: center;
            margin-bottom: 20px;
            padding-bottom: 20px;
            border-bottom: 1px solid #eee;
        }

        .status-icon {
            width: 60px;
            height: 60px;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            margin-right: 20px;
            flex-shrink: 0;
        }

        .status-icon.in_transit {
            background-color: #3498db;
            color: white;
        }

        .status-icon.delivered {
            background-color: #2ecc71;
            color: white;
        }

        .status-icon.failed {
            background-color: #e74c3c;
            color: white;
        }

        .status-icon.pending,
        .status-icon.ready_to_ship {
            background-color: #f39c12;
            color: white;
        }

        .status-icon i {
            font-size: 24px;
        }

        .status-details {
            flex-grow: 1;
        }

        .status-details h2 {
            margin: 0 0 5px 0;
            font-size: 18px;
            color: #333;
        }

        .status-details p {
            margin: 0;
            color: #666;
        }

        .tracking-progress {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
            position: relative;
        }

        .progress-bar {
            position: absolute;
            top: 25px;
            left: 0;
            height: 2px;
            background-color: #ddd;
            width: 100%;
            z-index: 1;
        }

        .progress-fill {
            position: absolute;
            top: 25px;
            left: 0;
            height: 2px;
            background-color: #3498db;
            z-index: 2;
        }

        .progress-step {
            z-index: 3;
            text-align: center;
            position: relative;
            width: 25%;
        }

        .step-icon {
            width: 50px;
            height: 50px;
            border-radius: 50%;
            background-color: #fff;
            border: 2px solid #ddd;
            display: flex;
            align-items: center;
            justify-content: center;
            margin: 0 auto;
            position: relative;
        }

        .step-icon.active {
            border-color: #3498db;
            background-color: #3498db;
            color: white;
        }

        .step-icon.completed {
            border-color: #2ecc71;
            background-color: #2ecc71;
            color: white;
        }

        .step-label {
            margin-top: 10px;
            font-size: 12px;
            color: #666;
        }

        .active .step-label {
            color: #333;
            font-weight: bold;
        }

        .tracking-details {
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 1px 3px rgba(0, 0, 0, 0.1);
            padding: 20px;
        }

        .tracking-details h3 {
            margin-top: 0;
            color: #333;
            font-size: 16px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .shipment-info {
            margin-bottom: 20px;
            display: grid;
            grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
            gap: 15px;
        }

        .info-item {
            margin-bottom: 10px;
        }

        .info-label {
            font-weight: bold;
            color: #666;
            display: block;
            margin-bottom: 5px;
            font-size: 13px;
        }

        .info-value {
            color: #333;
        }

        .tracking-timeline {
            position: relative;
            padding-left: 30px;
        }

        .timeline-line {
            position: absolute;
            top: 0;
            bottom: 0;
            left: 15px;
            width: 2px;
            background-color: #ddd;
        }

        .timeline-item {
            position: relative;
            padding: 15px 0;
        }

        .timeline-point {
            position: absolute;
            left: -30px;
            width: 12px;
            height: 12px;
            border-radius: 50%;
            background-color: #ddd;
            top: 18px;
        }

        .timeline-item.current .timeline-point {
            background-color: #3498db;
            width: 16px;
            height: 16px;
            left: -32px;
            border: 2px solid #f0f8ff;
        }

        .timeline-date {
            margin-bottom: 5px;
            color: #3498db;
            font-weight: bold;
        }

        .timeline-content {
            background-color: #f8f9fa;
            padding: 12px 15px;
            border-radius: 5px;
            box-shadow: 0 1px 2px rgba(0, 0, 0, 0.05);
        }

        .timeline-item.current .timeline-content {
            background-color: #e8f4fc;
            box-shadow: 0 1px 3px rgba(52, 152, 219, 0.1);
        }

        .timeline-location {
            font-weight: bold;
            margin-bottom: 5px;
        }

        .timeline-description {
            color: #666;
        }

        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        .back-btn {
            position: absolute;
            top: 20px;
            right: 20px;
            padding: 8px 15px;
            background-color: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            text-decoration: none;
            font-size: 14px;
        }

        .back-btn:hover {
            background-color: #2980b9;
        }

        @media (max-width: 768px) {
            .tracking-progress {
                flex-wrap: wrap;
            }

            .progress-step {
                width: 50%;
                margin-bottom: 20px;
            }

            .progress-bar,
            .progress-fill {
                display: none;
            }
        }
    </style>
</head>

<body>
    <div class="content">
        <div class="tracking-header">
            <a href="<?= $return_url ?>" class="back-btn">返回<?= $return_url == 'tracking_list.php' ? '物流追踪列表' : '发货管理' ?></a>
            <h1>物流追踪</h1>

            <?php if (!empty($error)): ?>
                <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
            <?php else: ?>
                <div class="tracking-status">
                    <div class="status-icon <?= $shipment_info['status'] ?>">
                        <?php if ($shipment_info['status'] == 'in_transit'): ?>
                            <i>🚚</i>
                        <?php elseif ($shipment_info['status'] == 'delivered'): ?>
                            <i>✓</i>
                        <?php elseif ($shipment_info['status'] == 'failed'): ?>
                            <i>✗</i>
                        <?php else: ?>
                            <i>📦</i>
                        <?php endif; ?>
                    </div>
                    <div class="status-details">
                        <h2>物流状态: <?= $current_status_text ?></h2>
                        <p>物流单号: <?= htmlspecialchars($tracking_number) ?></p>
                        <p>物流公司: <?= htmlspecialchars($shipment_info['carrier_name']) ?></p>
                        <?php if ($shipment_info['status'] == 'in_transit' && $days_remaining > 0): ?>
                            <p>预计还需 <?= $days_remaining ?> 天送达</p>
                        <?php elseif ($shipment_info['status'] == 'in_transit' && $days_remaining < 0): ?>
                            <p>已超过预计送达时间 <?= abs($days_remaining) ?> 天</p>
                        <?php elseif ($shipment_info['status'] == 'delivered'): ?>
                            <p>包裹已于 <?= date('Y-m-d H:i', strtotime($tracking_info[0]['time'])) ?> 送达</p>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="tracking-progress">
                    <div class="progress-bar"></div>
                    <div class="progress-fill" style="width: 
                        <?php
                        if ($shipment_info['status'] == 'pending' || $shipment_info['status'] == 'ready_to_ship') {
                            echo "0%";
                        } elseif ($shipment_info['status'] == 'shipped') {
                            echo "25%";
                        } elseif ($shipment_info['status'] == 'in_transit') {
                            echo "50%";
                        } elseif ($shipment_info['status'] == 'delivered') {
                            echo "100%";
                        } elseif ($shipment_info['status'] == 'failed') {
                            echo "50%";
                        } else {
                            echo "0%";
                        }
                        ?>
                    "></div>

                    <div class="progress-step">
                        <div class="step-icon <?= in_array($shipment_info['status'], ['shipped', 'in_transit', 'delivered']) ? 'completed' : ($shipment_info['status'] == 'ready_to_ship' ? 'active' : '') ?>">1</div>
                        <div class="step-label">已发货</div>
                    </div>

                    <div class="progress-step">
                        <div class="step-icon <?= in_array($shipment_info['status'], ['in_transit', 'delivered']) ? 'completed' : ($shipment_info['status'] == 'shipped' ? 'active' : '') ?>">2</div>
                        <div class="step-label">运输中</div>
                    </div>

                    <div class="progress-step">
                        <div class="step-icon <?= $shipment_info['status'] == 'delivered' ? 'completed' : ($shipment_info['status'] == 'in_transit' ? 'active' : '') ?>">3</div>
                        <div class="step-label">派送中</div>
                    </div>

                    <div class="progress-step">
                        <div class="step-icon <?= $shipment_info['status'] == 'delivered' ? 'completed' : '' ?>">4</div>
                        <div class="step-label">已送达</div>
                    </div>
                </div>
            <?php endif; ?>
        </div>

        <?php if (!empty($shipment_info) && empty($error)): ?>
            <div class="tracking-details">
                <h3>物流信息</h3>

                <div class="shipment-info">
                    <div class="info-item">
                        <span class="info-label">订单号</span>
                        <span class="info-value"><?= htmlspecialchars($shipment_info['order_number']) ?></span>
                    </div>

                    <div class="info-item">
                        <span class="info-label">收件人</span>
                        <span class="info-value"><?= htmlspecialchars($shipment_info['customer_name']) ?></span>
                    </div>

                    <div class="info-item">
                        <span class="info-label">收货地址</span>
                        <span class="info-value"><?= htmlspecialchars($shipment_info['delivery_address'] ?? '未知') ?></span>
                    </div>

                    <div class="info-item">
                        <span class="info-label">发货日期</span>
                        <span class="info-value"><?= date('Y-m-d H:i', strtotime($shipment_info['shipment_date'])) ?></span>
                    </div>

                    <div class="info-item">
                        <span class="info-label">预计送达日期</span>
                        <span class="info-value">
                            <?= !empty($shipment_info['estimated_delivery_date']) ? date('Y-m-d', strtotime($shipment_info['estimated_delivery_date'])) : '未知' ?>
                        </span>
                    </div>

                    <div class="info-item">
                        <span class="info-label">物流服务类型</span>
                        <span class="info-value"><?= htmlspecialchars($shipment_info['service_type'] ?? '标准快递') ?></span>
                    </div>
                </div>

                <h3>物流跟踪详情</h3>

                <div class="tracking-timeline">
                    <div class="timeline-line"></div>

                    <?php foreach ($tracking_info as $node): ?>
                        <div class="timeline-item <?= $node['is_current'] ? 'current' : '' ?>">
                            <div class="timeline-point"></div>
                            <div class="timeline-date"><?= date('Y-m-d H:i', strtotime($node['time'])) ?></div>
                            <div class="timeline-content">
                                <div class="timeline-location"><?= htmlspecialchars($node['location']) ?></div>
                                <div class="timeline-description"><?= htmlspecialchars($node['description']) ?></div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif; ?>
    </div>
</body>

</html>