<?php
// production/equipment_management.php
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // 添加或编辑设备
        if (isset($_POST['action']) && ($_POST['action'] === 'add_equipment' || $_POST['action'] === 'edit_equipment')) {
            $equipment_id = $_POST['equipment_id'] ?? '';
            $name = $_POST['name'] ?? '';
            $model = $_POST['model'] ?? '';
            $asset_number = $_POST['asset_number'] ?? '';
            $purchase_date = !empty($_POST['purchase_date']) ? $_POST['purchase_date'] : null;
            $status = $_POST['status'] ?? '';
            $location = $_POST['location'] ?? '';
            $last_maintenance_date = !empty($_POST['last_maintenance_date']) ? $_POST['last_maintenance_date'] : null;
            $next_maintenance_date = !empty($_POST['next_maintenance_date']) ? $_POST['next_maintenance_date'] : null;

            // 验证必填字段
            if (empty($name) || empty($asset_number) || empty($status)) {
                throw new Exception('设备名称、资产编号和状态为必填项');
            }

            // 检查资产编号是否已存在（添加设备时）
            if ($_POST['action'] === 'add_equipment') {
                $check_stmt = $pdo->prepare("SELECT id FROM equipment WHERE asset_number = ?");
                $check_stmt->execute([$asset_number]);
                if ($check_stmt->fetch()) {
                    throw new Exception('资产编号已存在，请使用其他编号');
                }

                // 插入新设备
                $stmt = $pdo->prepare("
                    INSERT INTO equipment 
                    (name, model, asset_number, purchase_date, status, location, last_maintenance_date, next_maintenance_date)
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?)
                ");
                $stmt->execute([
                    $name,
                    $model,
                    $asset_number,
                    $purchase_date,
                    $status,
                    $location,
                    $last_maintenance_date,
                    $next_maintenance_date
                ]);

                $success_message = "设备 $name 添加成功";
            } else {
                // 编辑已有设备
                if (empty($equipment_id)) {
                    throw new Exception('设备ID不能为空');
                }

                // 检查设备是否存在
                $check_stmt = $pdo->prepare("SELECT id FROM equipment WHERE id = ?");
                $check_stmt->execute([$equipment_id]);
                if (!$check_stmt->fetch()) {
                    throw new Exception('设备不存在');
                }

                // 检查资产编号是否已被其他设备使用
                $check_stmt = $pdo->prepare("SELECT id FROM equipment WHERE asset_number = ? AND id != ?");
                $check_stmt->execute([$asset_number, $equipment_id]);
                if ($check_stmt->fetch()) {
                    throw new Exception('资产编号已被其他设备使用，请使用其他编号');
                }

                // 更新设备信息
                $stmt = $pdo->prepare("
                    UPDATE equipment 
                    SET name = ?, model = ?, asset_number = ?, purchase_date = ?,
                        status = ?, location = ?, last_maintenance_date = ?, next_maintenance_date = ?
                    WHERE id = ?
                ");
                $stmt->execute([
                    $name,
                    $model,
                    $asset_number,
                    $purchase_date,
                    $status,
                    $location,
                    $last_maintenance_date,
                    $next_maintenance_date,
                    $equipment_id
                ]);

                $success_message = "设备 $name 更新成功";
            }
        }

        // 添加维护记录
        if (isset($_POST['action']) && $_POST['action'] === 'add_maintenance') {
            $equipment_id = $_POST['equipment_id'] ?? '';
            $maintenance_date = $_POST['maintenance_date'] ?? '';
            $maintenance_type = $_POST['maintenance_type'] ?? '';
            $description = $_POST['description'] ?? '';
            $cost = !empty($_POST['cost']) ? $_POST['cost'] : null;
            $performed_by = $_POST['performed_by'] ?? '';
            $status = $_POST['status'] ?? '';
            $next_maintenance_date = !empty($_POST['next_maintenance_date']) ? $_POST['next_maintenance_date'] : null;

            // 验证必填字段
            if (empty($equipment_id) || empty($maintenance_date) || empty($maintenance_type) || empty($status)) {
                throw new Exception('设备ID、维护日期、维护类型和状态为必填项');
            }

            // 检查设备是否存在
            $check_stmt = $pdo->prepare("SELECT name FROM equipment WHERE id = ?");
            $check_stmt->execute([$equipment_id]);
            $equipment = $check_stmt->fetch();
            if (!$equipment) {
                throw new Exception('设备不存在');
            }

            // 开始事务
            $pdo->beginTransaction();

            // 插入维护记录
            $stmt = $pdo->prepare("
                INSERT INTO equipment_maintenance 
                (equipment_id, maintenance_date, maintenance_type, description, cost, performed_by, status, next_maintenance_date)
                VALUES (?, ?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $equipment_id,
                $maintenance_date,
                $maintenance_type,
                $description,
                $cost,
                $performed_by,
                $status,
                $next_maintenance_date
            ]);

            // 如果维护已完成，更新设备的最后维护日期和下次维护日期
            if ($status === 'completed') {
                $update_stmt = $pdo->prepare("
                    UPDATE equipment 
                    SET last_maintenance_date = ?, 
                        next_maintenance_date = ?,
                        status = CASE WHEN status = 'maintenance' THEN 'operational' ELSE status END
                    WHERE id = ?
                ");
                $update_stmt->execute([$maintenance_date, $next_maintenance_date, $equipment_id]);
            } else if ($maintenance_type === 'repair' && $status === 'in_progress') {
                // 如果是维修且状态为进行中，更新设备状态为维护中
                $update_stmt = $pdo->prepare("
                    UPDATE equipment 
                    SET status = 'maintenance'
                    WHERE id = ?
                ");
                $update_stmt->execute([$equipment_id]);
            }

            // 记录活动日志
            $stmt = $pdo->prepare("
                INSERT INTO activity_log 
                (user_id, username, action, target_type, target_id, details, ip_address) 
                VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $stmt->execute([
                $_SESSION['user_id'],
                $_SESSION['username'],
                '添加设备维护记录',
                'equipment',
                $equipment_id,
                json_encode([
                    'equipment_name' => $equipment['name'],
                    'maintenance_type' => $maintenance_type,
                    'maintenance_date' => $maintenance_date
                ]),
                $_SERVER['REMOTE_ADDR']
            ]);

            $pdo->commit();
            $success_message = "设备 {$equipment['name']} 的维护记录添加成功";
        }

        // 重定向，避免表单重复提交
        header("Location: equipment_management.php");
        exit;
    } catch (Exception $e) {
        if (isset($pdo) && $pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $error_message = '操作失败: ' . $e->getMessage();
    }
}

// 获取所有设备数据
$equipment = [];
$stmt = $pdo->prepare("
    SELECT id, name, model, asset_number, purchase_date, status, location, 
           last_maintenance_date, next_maintenance_date
    FROM equipment
    ORDER BY id ASC
");
$stmt->execute();
$equipment = $stmt->fetchAll();

// 处理设备维护记录表创建
try {
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `equipment_maintenance` (
          `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '维护记录ID',
          `equipment_id` INT UNSIGNED NOT NULL COMMENT '设备ID',
          `maintenance_date` DATE NOT NULL COMMENT '维护日期',
          `maintenance_type` ENUM('routine', 'repair', 'inspection') NOT NULL COMMENT '维护类型',
          `description` TEXT DEFAULT NULL COMMENT '维护描述',
          `cost` DECIMAL(10, 2) DEFAULT NULL COMMENT '维护费用',
          `performed_by` VARCHAR(100) DEFAULT NULL COMMENT '维护人员',
          `status` ENUM('pending', 'in_progress', 'completed') NOT NULL DEFAULT 'pending' COMMENT '维护状态',
          `next_maintenance_date` DATE DEFAULT NULL COMMENT '下次维护日期',
          `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
          `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
          PRIMARY KEY (`id`),
          KEY `idx_equipment_id` (`equipment_id`),
          KEY `idx_maintenance_date` (`maintenance_date`),
          KEY `idx_next_maintenance` (`next_maintenance_date`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='设备维护记录表'
    ");
} catch (PDOException $e) {
    // 表已存在或其他错误，不影响继续执行
    $error_message = '创建表失败: ' . $e->getMessage();
}

// 获取设备维护记录
$maintenance_records = [];
try {
    $stmt = $pdo->prepare("
        SELECT em.*, e.name as equipment_name
        FROM equipment_maintenance em
        JOIN equipment e ON em.equipment_id = e.id
        ORDER BY em.maintenance_date DESC
    ");
    $stmt->execute();
    $maintenance_records = $stmt->fetchAll();
} catch (PDOException $e) {
    // 表可能不存在，使用空数组继续
    $maintenance_records = [];
}

// 辅助函数：获取设备状态中文名称
function getStatusName($status)
{
    $statusMap = [
        'operational' => '运行中',
        'maintenance' => '维护中',
        'idle' => '闲置',
        'retired' => '已报废'
    ];
    return $statusMap[$status] ?? $status;
}

// 辅助函数：获取设备状态对应的CSS类
function getStatusClass($status)
{
    $classMap = [
        'operational' => 'status-operational',
        'maintenance' => 'status-maintenance',
        'idle' => 'status-idle',
        'retired' => 'status-retired'
    ];
    return $classMap[$status] ?? '';
}

// 辅助函数：获取维护类型中文名称
function getMaintenanceTypeName($type)
{
    $typeMap = [
        'routine' => '例行维护',
        'repair' => '设备维修',
        'inspection' => '设备检查'
    ];
    return $typeMap[$type] ?? $type;
}

// 辅助函数：获取维护状态中文名称
function getMaintenanceStatusName($status)
{
    $statusMap = [
        'pending' => '待执行',
        'in_progress' => '进行中',
        'completed' => '已完成'
    ];
    return $statusMap[$status] ?? $status;
}

// 辅助函数：检查是否需要维护提醒
function needsMaintenance($next_maintenance_date)
{
    if (empty($next_maintenance_date)) {
        return false;
    }

    $today = new DateTime();
    $next_date = new DateTime($next_maintenance_date);
    $days_diff = $today->diff($next_date)->days;

    // 如果下次维护日期已经过期或在7天内，返回true
    if ($next_date < $today || $days_diff <= 7) {
        return true;
    }
    return false;
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>设备管理与维护 - 果易管系统</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css" rel="stylesheet">
    <style>
        /* 页面样式 */
        .container {
            max-width: 1200px;
            margin: 30px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        h2 {
            text-align: center;
            color: #333;
            margin-bottom: 20px;
        }

        /* 设备状态样式 */
        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            text-align: center;
            color: white;
        }

        .status-operational {
            background-color: #2ecc71;
        }

        .status-maintenance {
            background-color: #e74c3c;
        }

        .status-idle {
            background-color: #f39c12;
        }

        .status-retired {
            background-color: #95a5a6;
        }

        /* 表格样式 */
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        th,
        td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        /* 按钮样式 */
        .btn-edit {
            background: #17a2b8;
            padding: 4px 8px;
            border-radius: 4px;
            color: white;
            display: inline-block;
            margin-right: 5px;
            text-decoration: none;
        }

        .btn-edit:hover {
            background: #138496;
            color: white;
            text-decoration: none;
        }

        .btn-success {
            background-color: #2ecc71;
            border-color: #27ae60;
            color: white;
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            margin-right: 5px;
            text-decoration: none;
        }

        .btn-success:hover {
            background-color: #27ae60;
            color: white;
            text-decoration: none;
        }

        .btn-warning {
            background-color: #f39c12;
            border-color: #d35400;
            color: white;
            display: inline-block;
            padding: 4px 8px;
            border-radius: 4px;
            margin-right: 5px;
            text-decoration: none;
        }

        .btn-warning:hover {
            background-color: #d35400;
            color: white;
            text-decoration: none;
        }

        .btn-delete {
            background: #dc3545;
            padding: 4px 8px;
            border-radius: 4px;
            color: white;
            display: inline-block;
            margin-right: 5px;
            text-decoration: none;
        }

        .btn-delete:hover {
            background: #c82333;
            color: white;
            text-decoration: none;
        }

        /* 表单样式 */
        .form-container {
            padding: 15px;
            background: #f9f9f9;
            border-radius: 6px;
            margin-top: 20px;
        }

        .hidden {
            display: none;
        }

        /* 提醒标志 */
        .maintenance-alert {
            color: #e74c3c;
            font-weight: bold;
        }

        /* 标签页样式 */
        .tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #dee2e6;
        }

        .tab {
            padding: 10px 15px;
            cursor: pointer;
            border: 1px solid transparent;
            border-top-left-radius: 4px;
            border-top-right-radius: 4px;
            margin-right: 5px;
            margin-bottom: -1px;
        }

        .tab.active {
            border-color: #dee2e6 #dee2e6 #fff;
            background-color: #fff;
            color: #495057;
            font-weight: bold;
        }

        .tab-content {
            display: none;
        }

        .tab-content.active {
            display: block;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>设备管理与维护</h2>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <!-- 标签页导航 -->
        <div class="tabs">
            <div class="tab active" onclick="switchTab('equipment-list')">设备列表</div>
            <div class="tab" onclick="switchTab('maintenance-records')">维护记录</div>
            <div class="tab" onclick="switchTab('maintenance-alerts')">维护提醒</div>
            <div class="tab" onclick="switchTab('equipment-form')">添加设备</div>
        </div>

        <!-- 设备列表 -->
        <div id="equipment-list" class="tab-content active">
            <div class="table-responsive">
                <table>
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>设备名称</th>
                            <th>型号</th>
                            <th>资产编号</th>
                            <th>购置日期</th>
                            <th>状态</th>
                            <th>位置</th>
                            <th>上次维护</th>
                            <th>下次维护</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($equipment)): ?>
                            <tr>
                                <td colspan="10" class="text-center">暂无设备数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($equipment as $equip): ?>
                                <?php $needs_maintenance = needsMaintenance($equip['next_maintenance_date']); ?>
                                <tr <?= $needs_maintenance ? 'class="table-warning"' : '' ?>>
                                    <td><?= $equip['id'] ?></td>
                                    <td><?= $equip['name'] ?></td>
                                    <td><?= $equip['model'] ?></td>
                                    <td><?= $equip['asset_number'] ?></td>
                                    <td><?= $equip['purchase_date'] ?></td>
                                    <td>
                                        <span class="status-tag <?= getStatusClass($equip['status']) ?>">
                                            <?= getStatusName($equip['status']) ?>
                                        </span>
                                    </td>
                                    <td><?= $equip['location'] ?></td>
                                    <td><?= $equip['last_maintenance_date'] ?: '-' ?></td>
                                    <td>
                                        <?= $equip['next_maintenance_date'] ?: '-' ?>
                                        <?php if ($needs_maintenance): ?>
                                            <span class="maintenance-alert">⚠️ 需要维护</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <a href="#" onclick="showEditForm(<?= htmlspecialchars(json_encode($equip)) ?>)" class="btn-edit">编辑</a>
                                        <a href="#" onclick="showMaintenanceForm(<?= $equip['id'] ?>, '<?= $equip['name'] ?>')" class="btn-warning">维护记录</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 维护记录列表 -->
        <div id="maintenance-records" class="tab-content">
            <div class="table-responsive">
                <table>
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>设备名称</th>
                            <th>维护日期</th>
                            <th>维护类型</th>
                            <th>描述</th>
                            <th>费用</th>
                            <th>维护人员</th>
                            <th>状态</th>
                            <th>下次维护日期</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($maintenance_records)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无维护记录</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($maintenance_records as $record): ?>
                                <tr>
                                    <td><?= $record['id'] ?></td>
                                    <td><?= $record['equipment_name'] ?></td>
                                    <td><?= $record['maintenance_date'] ?></td>
                                    <td><?= getMaintenanceTypeName($record['maintenance_type']) ?></td>
                                    <td><?= $record['description'] ?></td>
                                    <td><?= $record['cost'] ? '¥' . number_format($record['cost'], 2) : '-' ?></td>
                                    <td><?= $record['performed_by'] ?: '-' ?></td>
                                    <td><?= getMaintenanceStatusName($record['status']) ?></td>
                                    <td><?= $record['next_maintenance_date'] ?: '-' ?></td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 维护提醒 -->
        <div id="maintenance-alerts" class="tab-content">
            <div class="alert alert-info">
                以下设备需要在近期（7天内）进行维护。请及时安排维护计划。
            </div>
            <div class="table-responsive">
                <table>
                    <thead>
                        <tr>
                            <th>设备名称</th>
                            <th>型号</th>
                            <th>资产编号</th>
                            <th>状态</th>
                            <th>位置</th>
                            <th>下次维护日期</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $has_alerts = false;
                        foreach ($equipment as $equip):
                            if (needsMaintenance($equip['next_maintenance_date'])):
                                $has_alerts = true;
                        ?>
                                <tr class="table-warning">
                                    <td><?= $equip['name'] ?></td>
                                    <td><?= $equip['model'] ?></td>
                                    <td><?= $equip['asset_number'] ?></td>
                                    <td>
                                        <span class="status-tag <?= getStatusClass($equip['status']) ?>">
                                            <?= getStatusName($equip['status']) ?>
                                        </span>
                                    </td>
                                    <td><?= $equip['location'] ?></td>
                                    <td>
                                        <?= $equip['next_maintenance_date'] ?>
                                        <span class="maintenance-alert">⚠️ 需要维护</span>
                                    </td>
                                    <td>
                                        <a href="#" onclick="showMaintenanceForm(<?= $equip['id'] ?>, '<?= $equip['name'] ?>')" class="btn-warning">添加维护记录</a>
                                    </td>
                                </tr>
                            <?php
                            endif;
                        endforeach;

                        if (!$has_alerts):
                            ?>
                            <tr>
                                <td colspan="7" class="text-center">目前没有需要提醒维护的设备</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 添加/编辑设备表单 -->
        <div id="equipment-form" class="tab-content">
            <div class="form-container">
                <h4 id="formTitle">添加新设备</h4>
                <form id="equipmentForm" method="post" action="equipment_management.php">
                    <input type="hidden" name="action" value="add_equipment">
                    <input type="hidden" id="equipment_id" name="equipment_id" value="">

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>设备名称 <span class="text-danger">*</span></label>
                                <input type="text" id="name" name="name" class="form-control" required>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>型号</label>
                                <input type="text" id="model" name="model" class="form-control">
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>资产编号 <span class="text-danger">*</span></label>
                                <input type="text" id="asset_number" name="asset_number" class="form-control" required>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>购置日期</label>
                                <input type="date" id="purchase_date" name="purchase_date" class="form-control">
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>状态 <span class="text-danger">*</span></label>
                                <select id="status" name="status" class="form-control" required>
                                    <option value="operational">运行中</option>
                                    <option value="maintenance">维护中</option>
                                    <option value="idle">闲置</option>
                                    <option value="retired">已报废</option>
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>存放位置</label>
                                <input type="text" id="location" name="location" class="form-control">
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>上次维护日期</label>
                                <input type="date" id="last_maintenance_date" name="last_maintenance_date" class="form-control">
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>下次维护日期</label>
                                <input type="date" id="next_maintenance_date" name="next_maintenance_date" class="form-control">
                            </div>
                        </div>
                    </div>

                    <div class="form-group text-center">
                        <button type="submit" class="btn btn-success">保存设备</button>
                        <button type="button" class="btn btn-secondary" onclick="resetForm()">重置</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- 添加维护记录表单 -->
        <div id="maintenanceForm" class="form-container hidden">
            <h4 id="maintenanceFormTitle">添加维护记录</h4>
            <form id="addMaintenanceForm" method="post" action="equipment_management.php">
                <input type="hidden" name="action" value="add_maintenance">
                <input type="hidden" id="maintenance_equipment_id" name="equipment_id" value="">

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>设备名称</label>
                            <input type="text" id="maintenance_equipment_name" class="form-control" readonly>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>维护日期 <span class="text-danger">*</span></label>
                            <input type="date" name="maintenance_date" class="form-control" required value="<?= date('Y-m-d') ?>">
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>维护类型 <span class="text-danger">*</span></label>
                            <select name="maintenance_type" class="form-control" required>
                                <option value="routine">例行维护</option>
                                <option value="repair">设备维修</option>
                                <option value="inspection">设备检查</option>
                            </select>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>维护状态 <span class="text-danger">*</span></label>
                            <select name="status" class="form-control" required>
                                <option value="pending">待执行</option>
                                <option value="in_progress">进行中</option>
                                <option value="completed">已完成</option>
                            </select>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>维护费用</label>
                            <input type="number" name="cost" step="0.01" min="0" class="form-control">
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>维护人员</label>
                            <input type="text" name="performed_by" class="form-control">
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-12">
                        <div class="form-group">
                            <label>维护描述</label>
                            <textarea name="description" class="form-control" rows="3"></textarea>
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-6">
                        <div class="form-group">
                            <label>下次维护日期</label>
                            <input type="date" name="next_maintenance_date" class="form-control">
                        </div>
                    </div>
                </div>

                <div class="form-group text-center">
                    <button type="submit" class="btn btn-success">保存记录</button>
                    <button type="button" class="btn btn-secondary" onclick="hideMaintenanceForm()">取消</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        // 切换标签页
        function switchTab(tabId) {
            // 移除所有标签和内容区域的活动类
            document.querySelectorAll('.tab').forEach(tab => {
                tab.classList.remove('active');
            });
            document.querySelectorAll('.tab-content').forEach(content => {
                content.classList.remove('active');
            });

            // 添加活动类到选中的标签和内容区域
            document.querySelector(`.tab[onclick="switchTab('${tabId}')"]`).classList.add('active');
            document.getElementById(tabId).classList.add('active');
        }

        // 显示编辑设备表单
        function showEditForm(equipment) {
            // 切换到设备表单标签页
            switchTab('equipment-form');

            // 更新表单标题
            document.getElementById('formTitle').innerText = '编辑设备';

            // 设置表单动作为编辑
            document.querySelector('#equipmentForm [name="action"]').value = 'edit_equipment';

            // 填充表单数据
            document.getElementById('equipment_id').value = equipment.id;
            document.getElementById('name').value = equipment.name;
            document.getElementById('model').value = equipment.model || '';
            document.getElementById('asset_number').value = equipment.asset_number || '';
            document.getElementById('purchase_date').value = equipment.purchase_date || '';
            document.getElementById('status').value = equipment.status;
            document.getElementById('location').value = equipment.location || '';
            document.getElementById('last_maintenance_date').value = equipment.last_maintenance_date || '';
            document.getElementById('next_maintenance_date').value = equipment.next_maintenance_date || '';

            // 滚动到表单位置
            document.getElementById('equipment-form').scrollIntoView({
                behavior: 'smooth'
            });
        }

        // 重置设备表单
        function resetForm() {
            document.getElementById('formTitle').innerText = '添加新设备';
            document.querySelector('#equipmentForm [name="action"]').value = 'add_equipment';
            document.getElementById('equipment_id').value = '';
            document.getElementById('equipmentForm').reset();
        }

        // 显示维护记录表单
        function showMaintenanceForm(equipmentId, equipmentName) {
            document.getElementById('maintenanceForm').classList.remove('hidden');
            document.getElementById('maintenance_equipment_id').value = equipmentId;
            document.getElementById('maintenance_equipment_name').value = equipmentName;
            document.getElementById('maintenanceFormTitle').innerText = '为 ' + equipmentName + ' 添加维护记录';

            // 滚动到表单位置
            document.getElementById('maintenanceForm').scrollIntoView({
                behavior: 'smooth'
            });
        }

        // 隐藏维护记录表单
        function hideMaintenanceForm() {
            document.getElementById('maintenanceForm').classList.add('hidden');
        }
    </script>
</body>

</html>