<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取产品列表（成品和半成品）用于创建生产计划
$products = $pdo->query("
    SELECT id, name, type, unit, specification 
    FROM products 
    WHERE type IN ('semi-finished', 'finished')
    ORDER BY type, name
")->fetchAll();

// 获取所有生产计划
$plans = $pdo->query("
    SELECT 
        pp.id, 
        pp.plan_number, 
        p.name AS product_name,
        p.type AS product_type,
        p.unit,
        pp.quantity_planned, 
        pp.plan_date, 
        pp.start_date, 
        pp.end_date, 
        pp.status,
        u.username AS created_by
    FROM production_plans pp
    JOIN products p ON pp.product_id = p.id
    LEFT JOIN users u ON pp.created_by_user_id = u.id
    ORDER BY pp.plan_date DESC
")->fetchAll();

// 生成新计划编号
$today = date('Ymd');
$stmt = $pdo->prepare("
    SELECT COUNT(*) 
    FROM production_plans 
    WHERE plan_number LIKE ?
");
$stmt->execute(["PP$today%"]);
$count = $stmt->fetchColumn() + 1;
$newPlanNumber = "PP$today" . str_pad($count, 3, '0', STR_PAD_LEFT);

// 处理表单提交 - 创建新生产计划
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'create_plan') {
    // 验证CSRF Token
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: production_plans.php");
        exit;
    }

    try {
        // 获取表单数据
        $product_id = (int)($_POST['product_id'] ?? 0);
        $quantity_planned = (float)($_POST['quantity_planned'] ?? 0);
        $plan_date = $_POST['plan_date'] ?? date('Y-m-d');
        $start_date = !empty($_POST['start_date']) ? $_POST['start_date'] : null;
        $end_date = !empty($_POST['end_date']) ? $_POST['end_date'] : null;

        // 数据验证
        if ($product_id <= 0 || $quantity_planned <= 0) {
            throw new Exception("请选择产品并输入有效的计划数量");
        }

        // 开始事务
        $pdo->beginTransaction();

        // 插入生产计划
        $stmt = $pdo->prepare("
            INSERT INTO production_plans 
            (plan_number, product_id, quantity_planned, plan_date, start_date, end_date, status, created_by_user_id) 
            VALUES (?, ?, ?, ?, ?, ?, 'planned', ?)
        ");
        $stmt->execute([
            $newPlanNumber,
            $product_id,
            $quantity_planned,
            $plan_date,
            $start_date,
            $end_date,
            $_SESSION['user_id']
        ]);

        // 记录操作日志
        $plan_id = $pdo->lastInsertId();
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '创建生产计划',
            'production_plan',
            $plan_id,
            json_encode([
                'plan_number' => $newPlanNumber,
                'product_id' => $product_id,
                'quantity_planned' => $quantity_planned
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "生产计划 $newPlanNumber 创建成功";

        // 重定向以防止表单重复提交
        header("Location: production_plans.php");
        exit;
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $_SESSION['error'] = "创建生产计划失败: " . $e->getMessage();
    }
}

// 处理计划状态更新
if ($_SERVER['REQUEST_METHOD'] === 'GET' && isset($_GET['action']) && $_GET['action'] === 'update_status') {
    // 验证参数
    $plan_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
    $new_status = $_GET['status'] ?? '';

    $valid_status = ['planned', 'in_progress', 'completed', 'cancelled'];

    if ($plan_id <= 0 || !in_array($new_status, $valid_status)) {
        $_SESSION['error'] = "无效的参数";
        header("Location: production_plans.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 获取当前计划信息
        $stmt = $pdo->prepare("SELECT plan_number, status FROM production_plans WHERE id = ?");
        $stmt->execute([$plan_id]);
        $plan = $stmt->fetch();

        if (!$plan) {
            throw new Exception("生产计划不存在");
        }

        // 更新状态
        $stmt = $pdo->prepare("UPDATE production_plans SET status = ? WHERE id = ?");
        $stmt->execute([$new_status, $plan_id]);

        // 记录日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '更新生产计划状态',
            'production_plan',
            $plan_id,
            json_encode([
                'plan_number' => $plan['plan_number'],
                'old_status' => $plan['status'],
                'new_status' => $new_status
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "计划 {$plan['plan_number']} 状态已更新为 " . getStatusName($new_status);
    } catch (Exception $e) {
        if ($pdo->inTransaction()) {
            $pdo->rollBack();
        }
        $_SESSION['error'] = $e->getMessage();
    }

    header("Location: production_plans.php");
    exit;
}

// 状态名称转换函数
function getStatusName($status)
{
    $statusMap = [
        'planned' => '已计划',
        'in_progress' => '进行中',
        'completed' => '已完成',
        'cancelled' => '已取消'
    ];
    return $statusMap[$status] ?? $status;
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产计划管理 - 果易管系统</title>
    <link rel="stylesheet" href="style.css">
    <style>
        /* 状态标签样式 */
        .status-tag {
            display: inline-block;
            padding: 3px 8px;
            border-radius: 4px;
            font-size: 12px;
            font-weight: bold;
            text-align: center;
            color: white;
        }

        .planned {
            background-color: #f1c40f;
            color: #000;
        }

        .in_progress {
            background-color: #3498db;
        }

        .completed {
            background-color: #2ecc71;
        }

        .cancelled {
            background-color: #e74c3c;
        }

        /* 简单标签页样式 */
        .simple-tabs {
            display: flex;
            margin-bottom: 20px;
            border-bottom: 1px solid #ddd;
        }

        .tab-btn {
            padding: 10px 15px;
            background: #f5f5f5;
            border: 1px solid #ddd;
            border-bottom: none;
            margin-right: 5px;
            border-radius: 5px 5px 0 0;
            cursor: pointer;
        }

        .tab-btn.active {
            background: #fff;
            border-bottom: 1px solid #fff;
            margin-bottom: -1px;
            font-weight: bold;
        }

        /* 链接按钮样式 */
        .btn-link {
            color: #fff;
            text-decoration: none;
            padding: 5px 10px;
            border-radius: 4px;
            margin-right: 5px;
            display: inline-block;
            background-color: #3498db;
            border: 1px solid #2980b9;
            font-size: 12px;
        }

        .btn-link:hover {
            background-color: #2980b9;
        }

        /* 按钮颜色变体 */
        .btn-success {
            background-color: #2ecc71;
            border-color: #27ae60;
        }

        .btn-success:hover {
            background-color: #27ae60;
        }

        .btn-danger {
            background-color: #e74c3c;
            border-color: #c0392b;
        }

        .btn-danger:hover {
            background-color: #c0392b;
        }

        .btn-warning {
            background-color: #f39c12;
            border-color: #d35400;
        }

        .btn-warning:hover {
            background-color: #d35400;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>生产计划管理</h2>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 简单标签页 -->
        <div class="simple-tabs">
            <div class="tab-btn active" onclick="showTab('plan-list')">生产计划列表</div>
            <div class="tab-btn" onclick="showTab('create-plan')">创建新计划</div>
        </div>

        <!-- 生产计划列表 -->
        <div id="plan-list" class="tab-content">
            <div class="table-container">
                <table>
                    <thead>
                        <tr>
                            <th>计划编号</th>
                            <th>产品</th>
                            <th>计划数量</th>
                            <th>计划日期</th>
                            <th>开始日期</th>
                            <th>结束日期</th>
                            <th>状态</th>
                            <th>创建人</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($plans)): ?>
                            <tr>
                                <td colspan="9" class="text-center">暂无生产计划数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($plans as $plan): ?>
                                <tr>
                                    <td><?= htmlspecialchars($plan['plan_number']) ?></td>
                                    <td>
                                        <?= htmlspecialchars($plan['product_name']) ?>
                                        (<?= $plan['product_type'] == 'semi-finished' ? '半成品' : '成品' ?>)
                                    </td>
                                    <td><?= number_format($plan['quantity_planned'], 2) ?> <?= htmlspecialchars($plan['unit']) ?></td>
                                    <td><?= date('Y-m-d', strtotime($plan['plan_date'])) ?></td>
                                    <td><?= $plan['start_date'] ? date('Y-m-d', strtotime($plan['start_date'])) : '-' ?></td>
                                    <td><?= $plan['end_date'] ? date('Y-m-d', strtotime($plan['end_date'])) : '-' ?></td>
                                    <td>
                                        <span class="status-tag <?= $plan['status'] ?>"><?= getStatusName($plan['status']) ?></span>
                                    </td>
                                    <td><?= htmlspecialchars($plan['created_by'] ?? '-') ?></td>
                                    <td class="plan-actions">
                                        <?php if ($plan['status'] === 'planned'): ?>
                                            <a href="production_plans.php?action=update_status&id=<?= $plan['id'] ?>&status=in_progress"
                                                onclick="return confirm('确认将计划标记为进行中？')"
                                                class="btn-link">开始</a>
                                        <?php elseif ($plan['status'] === 'in_progress'): ?>
                                            <a href="production_plans.php?action=update_status&id=<?= $plan['id'] ?>&status=completed"
                                                onclick="return confirm('确认将计划标记为已完成？')"
                                                class="btn-link btn-success">完成</a>
                                        <?php endif; ?>

                                        <?php if ($plan['status'] !== 'cancelled' && $plan['status'] !== 'completed'): ?>
                                            <a href="production_plans.php?action=update_status&id=<?= $plan['id'] ?>&status=cancelled"
                                                onclick="return confirm('确认取消该计划？')"
                                                class="btn-link btn-danger">取消</a>
                                        <?php endif; ?>

                                        <a href="batch_management.php?plan_id=<?= $plan['id'] ?>" class="btn-link btn-warning">批次管理</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>

        <!-- 创建新计划表单 -->
        <div id="create-plan" class="tab-content" style="display: none;">
            <div class="form-container">
                <h3>创建新生产计划</h3>
                <form method="POST" action="production_plans.php">
                    <?= csrf_field() ?>
                    <input type="hidden" name="action" value="create_plan">

                    <div class="form-group">
                        <label>计划编号</label>
                        <input type="text" value="<?= htmlspecialchars($newPlanNumber) ?>" readonly>
                        <small>系统自动生成</small>
                    </div>

                    <div class="form-group">
                        <label>产品</label>
                        <select name="product_id" required>
                            <option value="">-- 请选择产品 --</option>
                            <optgroup label="半成品">
                                <?php foreach ($products as $product): ?>
                                    <?php if ($product['type'] === 'semi-finished'): ?>
                                        <option value="<?= $product['id'] ?>">
                                            <?= htmlspecialchars($product['name']) ?>
                                            (<?= htmlspecialchars($product['specification'] ?? '-') ?>)
                                        </option>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </optgroup>
                            <optgroup label="成品">
                                <?php foreach ($products as $product): ?>
                                    <?php if ($product['type'] === 'finished'): ?>
                                        <option value="<?= $product['id'] ?>">
                                            <?= htmlspecialchars($product['name']) ?>
                                            (<?= htmlspecialchars($product['specification'] ?? '-') ?>)
                                        </option>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </optgroup>
                        </select>
                    </div>

                    <div class="form-group">
                        <label>计划生产数量</label>
                        <input type="number" name="quantity_planned" step="0.01" min="0.01" required>
                    </div>

                    <div class="form-group">
                        <label>计划日期</label>
                        <input type="date" name="plan_date" value="<?= date('Y-m-d') ?>" required>
                    </div>

                    <div class="form-group">
                        <label>计划开始日期 (可选)</label>
                        <input type="date" name="start_date">
                    </div>

                    <div class="form-group">
                        <label>计划完成日期 (可选)</label>
                        <input type="date" name="end_date">
                    </div>

                    <button type="submit" class="btn-link btn-success">创建生产计划</button>
                </form>
            </div>
        </div>
    </div>

    <script>
        // 标签页切换函数
        function showTab(tabId) {
            // 隐藏所有标签内容
            document.querySelectorAll('.tab-content').forEach(tab => {
                tab.style.display = 'none';
            });

            // 显示选中的标签内容
            document.getElementById(tabId).style.display = 'block';

            // 更新标签按钮样式
            document.querySelectorAll('.tab-btn').forEach(btn => {
                btn.classList.remove('active');
            });

            // 找到对应的按钮并设为活动状态
            document.querySelector(`.tab-btn[onclick="showTab('${tabId}')"]`).classList.add('active');
        }
    </script>
</body>

</html>