<?php
// production/production_process.php
require_once '../config.php';

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取批次列表
$batches = [];
$stmt = $pdo->prepare("
    SELECT pb.id, pb.batch_number, p.name as product_name, p.type as product_type, 
           pb.quantity_planned, pb.quantity_produced, pb.start_time, pb.end_time, 
           pb.status, pb.notes
    FROM production_batches pb
    JOIN products p ON pb.product_id = p.id
    WHERE pb.status IN ('planned', 'in_progress')
    ORDER BY pb.start_time DESC, pb.id DESC
");
$stmt->execute();
$batches = $stmt->fetchAll();

// 创建production_process_steps表（如果不存在）
try {
    $pdo->exec("
        CREATE TABLE IF NOT EXISTS `production_process_steps` (
          `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '步骤ID',
          `batch_id` INT UNSIGNED NOT NULL COMMENT '生产批次ID',
          `step_name` ENUM('水果清洗', '腌制', '烘干', '包装') NOT NULL COMMENT '步骤名称',
          `status` ENUM('pending', 'in_progress', 'completed', 'skipped') NOT NULL DEFAULT 'pending' COMMENT '步骤状态',
          `start_time` DATETIME DEFAULT NULL COMMENT '开始时间',
          `end_time` DATETIME DEFAULT NULL COMMENT '结束时间',
          `operator_id` INT UNSIGNED DEFAULT NULL COMMENT '操作员ID',
          `temperature` DECIMAL(5, 2) DEFAULT NULL COMMENT '温度记录',
          `humidity` DECIMAL(5, 2) DEFAULT NULL COMMENT '湿度记录',
          `notes` TEXT DEFAULT NULL COMMENT '备注',
          `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
          `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
          PRIMARY KEY (`id`),
          UNIQUE KEY `uk_batch_step` (`batch_id`, `step_name`),
          KEY `idx_process_batch` (`batch_id`),
          KEY `idx_process_status` (`status`),
          KEY `idx_process_operator` (`operator_id`)
        ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='生产流程步骤记录表'
    ");
} catch (PDOException $e) {
    // 表已存在或其他错误，不影响继续执行
    $error_message = '创建表失败: ' . $e->getMessage();
}

// 处理流程步骤更新
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    try {
        if ($_POST['action'] === 'update_process') {
            // 获取表单数据
            $batch_id = $_POST['batch_id'] ?? 0;
            $step = $_POST['step'] ?? '';
            $status = $_POST['status'] ?? '';
            $start_time = $_POST['start_time'] ?? null;
            $end_time = $_POST['end_time'] ?? null;
            $operator_id = $_SESSION['user_id'];
            $notes = $_POST['notes'] ?? '';
            $temperature = !empty($_POST['temperature']) ? $_POST['temperature'] : null;
            $humidity = !empty($_POST['humidity']) ? $_POST['humidity'] : null;

            // 验证必填字段
            $errors = [];
            if (empty($batch_id)) {
                $errors[] = '批次ID不能为空';
            }
            if (empty($step)) {
                $errors[] = '请选择流程步骤';
            }
            if (empty($status)) {
                $errors[] = '请选择步骤状态';
            }

            // 如果有验证错误，显示错误信息并停止处理
            if (!empty($errors)) {
                $error_message = '表单验证失败：' . implode('，', $errors);
            } else {
                // 检查批次是否存在
                $check_stmt = $pdo->prepare("SELECT id FROM production_batches WHERE id = ?");
                $check_stmt->execute([$batch_id]);
                if (!$check_stmt->fetch()) {
                    throw new Exception('批次不存在');
                }

                // 格式化日期时间
                if (!empty($start_time)) {
                    $start_time = date('Y-m-d H:i:s', strtotime($start_time));
                } else {
                    $start_time = null; // 确保空值为null而不是空字符串
                }
                if (!empty($end_time)) {
                    $end_time = date('Y-m-d H:i:s', strtotime($end_time));
                } else {
                    $end_time = null; // 确保空值为null而不是空字符串
                }

                // 记录流程步骤
                $stmt = $pdo->prepare("
                    INSERT INTO production_process_steps 
                    (batch_id, step_name, status, start_time, end_time, operator_id, notes, temperature, humidity)
                    VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)
                    ON DUPLICATE KEY UPDATE 
                    status = VALUES(status),
                    start_time = CASE WHEN VALUES(start_time) IS NOT NULL THEN VALUES(start_time) ELSE start_time END,
                    end_time = CASE WHEN VALUES(end_time) IS NOT NULL THEN VALUES(end_time) ELSE end_time END,
                    notes = CASE WHEN VALUES(notes) != '' THEN VALUES(notes) ELSE notes END,
                    temperature = CASE WHEN VALUES(temperature) IS NOT NULL THEN VALUES(temperature) ELSE temperature END,
                    humidity = CASE WHEN VALUES(humidity) IS NOT NULL THEN VALUES(humidity) ELSE humidity END
                ");

                $stmt->execute([
                    $batch_id,
                    $step,
                    $status,
                    $start_time,
                    $end_time,
                    $operator_id,
                    $notes,
                    $temperature,
                    $humidity
                ]);

                // 如果是完成步骤，更新批次状态
                if ($status === 'completed' && $step === '包装') {
                    $update_stmt = $pdo->prepare("
                        UPDATE production_batches 
                        SET status = 'completed', end_time = NOW() 
                        WHERE id = ?
                    ");
                    $update_stmt->execute([$batch_id]);
                }

                $success_message = '生产流程更新成功';

                // 重置表单，避免重复提交
                echo "<script>setTimeout(function() { window.location.href = 'production_process.php'; }, 1500);</script>";
            }
        }
    } catch (Exception $e) {
        $error_message = '操作失败: ' . $e->getMessage();
    }
}

// 获取流程步骤数据
$process_steps = [];
if (!empty($batches)) {
    $batch_ids = array_column($batches, 'id');

    // 检查表是否存在并有数据
    try {
        $batch_ids_str = implode(',', array_fill(0, count($batch_ids), '?'));

        $stmt = $pdo->prepare("
            SELECT * FROM production_process_steps 
            WHERE batch_id IN ($batch_ids_str)
            ORDER BY batch_id, start_time
        ");
        $stmt->execute($batch_ids);
        $steps_data = $stmt->fetchAll();

        // 整理数据结构
        foreach ($steps_data as $step) {
            $process_steps[$step['batch_id']][$step['step_name']] = $step;
        }
    } catch (PDOException $e) {
        // 可能表不存在或其他查询错误，使用空数组继续
        $process_steps = [];
    }
}

// 获取用户列表（操作员）
$users = [];
$stmt = $pdo->prepare("SELECT id, username, full_name FROM users WHERE is_active = 1");
$stmt->execute();
$users = $stmt->fetchAll();

// 辅助函数：获取步骤状态对应的标签样式
function getStatusClass($status)
{
    switch ($status) {
        case 'completed':
            return 'status-completed';
        case 'in_progress':
            return 'status-in-progress';
        case 'skipped':
            return 'status-skipped';
        default:
            return 'status-pending';
    }
}

// 辅助函数：获取步骤状态中文名称
function getStatusName($status)
{
    switch ($status) {
        case 'completed':
            return '已完成';
        case 'in_progress':
            return '进行中';
        case 'skipped':
            return '已跳过';
        default:
            return '待处理';
    }
}

// 辅助函数：获取用户名
function getUserName($user_id, $users)
{
    foreach ($users as $user) {
        if ($user['id'] == $user_id) {
            return $user['full_name'] ?: $user['username'];
        }
    }
    return '未知';
}

// 定义流程步骤
$process_step_names = ['水果清洗', '腌制', '烘干', '包装'];
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>生产流程管理 - 果易管系统</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/4.6.0/css/bootstrap.min.css" rel="stylesheet">
    <style>
        /* 页面样式 */
        .container {
            max-width: 1200px;
            margin: 30px auto;
            padding: 20px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        h2 {
            text-align: center;
            color: #333;
            margin-bottom: 20px;
        }

        /* 流程步骤样式 */
        .process-flow {
            display: flex;
            justify-content: space-between;
            margin: 20px 0;
            padding: 10px;
            background: #f8f9fa;
            border-radius: 8px;
        }

        .process-step {
            flex: 1;
            text-align: center;
            padding: 10px;
            margin: 0 5px;
            border-radius: 6px;
            position: relative;
        }

        .process-step:not(:last-child)::after {
            content: '→';
            position: absolute;
            right: -10px;
            top: 50%;
            transform: translateY(-50%);
            font-size: 20px;
            color: #aaa;
        }

        /* 状态样式 */
        .status-completed {
            background-color: #2ecc71;
            color: white;
        }

        .status-in-progress {
            background-color: #3498db;
            color: white;
        }

        .status-pending {
            background-color: #f39c12;
            color: white;
        }

        .status-skipped {
            background-color: #95a5a6;
            color: white;
        }

        /* 表格样式 */
        table {
            width: 100%;
            border-collapse: collapse;
            margin-bottom: 20px;
        }

        th,
        td {
            padding: 12px;
            border: 1px solid #ddd;
            text-align: left;
        }

        th {
            background-color: #f5f5f5;
            font-weight: bold;
        }

        /* 按钮样式 */
        .btn-edit {
            background: #17a2b8;
            padding: 4px 8px;
            border-radius: 4px;
            color: white;
        }

        .btn-success {
            background-color: #2ecc71;
            border-color: #27ae60;
            color: white;
        }

        .btn-warning {
            background-color: #f39c12;
            border-color: #d35400;
            color: white;
        }

        /* 表单样式 */
        .form-container {
            padding: 15px;
            background: #f9f9f9;
            border-radius: 6px;
            margin-top: 20px;
        }

        .hidden {
            display: none;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>生产流程管理</h2>

        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?= $success_message ?></div>
        <?php endif; ?>

        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?= $error_message ?></div>
        <?php endif; ?>

        <?php if (empty($batches)): ?>
            <div class="alert alert-info">目前没有进行中的生产批次。请先在批次管理中创建批次。</div>
        <?php else: ?>
            <div class="table-responsive">
                <table>
                    <thead>
                        <tr>
                            <th>批次号</th>
                            <th>产品名称</th>
                            <th>计划数量</th>
                            <th>开始时间</th>
                            <th>状态</th>
                            <th>流程进度</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($batches as $batch): ?>
                            <tr>
                                <td><?= $batch['batch_number'] ?></td>
                                <td><?= $batch['product_name'] ?></td>
                                <td><?= $batch['quantity_planned'] ?></td>
                                <td><?= $batch['start_time'] ?: '-' ?></td>
                                <td><?= $batch['status'] === 'in_progress' ? '进行中' : '已计划' ?></td>
                                <td>
                                    <div class="process-flow">
                                        <?php foreach ($process_step_names as $step): ?>
                                            <?php
                                            $step_status = $process_steps[$batch['id']][$step]['status'] ?? 'pending';
                                            $status_class = getStatusClass($step_status);
                                            ?>
                                            <div class="process-step <?= $status_class ?>">
                                                <?= $step ?>
                                                <div><?= getStatusName($step_status) ?></div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>
                                </td>
                                <td>
                                    <a href="#" onclick="showProcessForm(<?= $batch['id'] ?>, '<?= $batch['batch_number'] ?>')" class="btn-warning">更新流程</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>

            <!-- 流程更新表单 -->
            <div id="processForm" class="form-container hidden">
                <h4 id="formTitle">更新生产流程</h4>
                <form method="post" onsubmit="return validateForm()">
                    <input type="hidden" name="action" value="update_process">
                    <input type="hidden" id="batch_id" name="batch_id" value="">

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>批次号</label>
                                <input type="text" id="batch_number" class="form-control" readonly>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>流程步骤 <span class="text-danger">*</span></label>
                                <select name="step" id="step" class="form-control" required>
                                    <option value="">--选择步骤--</option>
                                    <?php foreach ($process_step_names as $step): ?>
                                        <option value="<?= $step ?>"><?= $step ?></option>
                                    <?php endforeach; ?>
                                </select>
                                <div class="invalid-feedback">请选择流程步骤</div>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>步骤状态 <span class="text-danger">*</span></label>
                                <select name="status" id="status" class="form-control" required>
                                    <option value="">--选择状态--</option>
                                    <option value="pending">待处理</option>
                                    <option value="in_progress">进行中</option>
                                    <option value="completed">已完成</option>
                                    <option value="skipped">已跳过</option>
                                </select>
                                <div class="invalid-feedback">请选择步骤状态</div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>开始时间</label>
                                <input type="datetime-local" name="start_time" id="start_time" class="form-control">
                                <small class="form-text text-muted">如不填写，将保留原记录或不设置</small>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>结束时间</label>
                                <input type="datetime-local" name="end_time" id="end_time" class="form-control">
                                <small class="form-text text-muted">如不填写，将保留原记录或不设置</small>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>操作员</label>
                                <input type="text" class="form-control" value="<?= $_SESSION['username'] ?>" readonly>
                            </div>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>温度 (°C)</label>
                                <input type="number" name="temperature" id="temperature" step="0.01" class="form-control" placeholder="例如: 25.5">
                                <small class="form-text text-muted">可选，请输入数字</small>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label>湿度 (%)</label>
                                <input type="number" name="humidity" id="humidity" step="0.01" class="form-control" placeholder="例如: 60.0">
                                <small class="form-text text-muted">可选，请输入数字</small>
                            </div>
                        </div>
                    </div>

                    <div class="form-group">
                        <label>备注</label>
                        <textarea name="notes" id="notes" class="form-control" rows="3" placeholder="可选，输入相关备注信息"></textarea>
                    </div>

                    <div class="form-group text-center">
                        <button type="submit" class="btn btn-success">提交更新</button>
                        <button type="button" class="btn btn-secondary" onclick="hideProcessForm()">取消</button>
                    </div>
                </form>
            </div>
        <?php endif; ?>
    </div>

    <script>
        // 显示流程更新表单
        function showProcessForm(batchId, batchNumber) {
            document.getElementById('processForm').classList.remove('hidden');
            document.getElementById('batch_id').value = batchId;
            document.getElementById('batch_number').value = batchNumber;
            document.getElementById('formTitle').innerText = '更新批次 ' + batchNumber + ' 的生产流程';

            // 重置表单
            document.getElementById('step').value = '';
            document.getElementById('status').value = '';
            document.getElementById('start_time').value = '';
            document.getElementById('end_time').value = '';
            document.getElementById('temperature').value = '';
            document.getElementById('humidity').value = '';
            document.getElementById('notes').value = '';

            // 滚动到表单位置
            document.getElementById('processForm').scrollIntoView({
                behavior: 'smooth'
            });
        }

        // 隐藏表单
        function hideProcessForm() {
            document.getElementById('processForm').classList.add('hidden');
        }

        // 表单验证
        function validateForm() {
            let isValid = true;
            const step = document.getElementById('step');
            const status = document.getElementById('status');

            // 重置所有错误提示
            document.querySelectorAll('.is-invalid').forEach(el => {
                el.classList.remove('is-invalid');
            });

            // 验证流程步骤
            if (!step.value) {
                step.classList.add('is-invalid');
                isValid = false;
            }

            // 验证步骤状态
            if (!status.value) {
                status.classList.add('is-invalid');
                isValid = false;
            }

            return isValid;
        }
    </script>
</body>

</html>