<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取入库记录ID
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$id) {
    $_SESSION['error'] = "未指定入库记录ID";
    header("Location: material_receiving.php");
    exit;
}

try {
    // 获取入库记录信息
    $stmt = $pdo->prepare("
        SELECT 
            mr.id,
            mr.received_date,
            mr.received_quantity,
            mr.batch_number,
            mr.quality_check_result,
            mr.inspection_notes,
            p.id AS product_id,
            p.name AS product_name,
            p.specification,
            p.unit,
            u.username AS inspector_name,
            sl.name AS location_name,
            po.id AS purchase_order_id,
            po.order_number,
            s.name AS supplier_name
        FROM material_receiving mr
        JOIN products p ON mr.product_id = p.id
        LEFT JOIN users u ON mr.inspector_id = u.id
        LEFT JOIN storage_locations sl ON mr.storage_location_id = sl.id
        LEFT JOIN purchase_order_items poi ON mr.purchase_order_item_id = poi.id
        LEFT JOIN purchase_orders po ON poi.purchase_order_id = po.id
        LEFT JOIN suppliers s ON po.supplier_id = s.id
        WHERE mr.id = ?
    ");
    $stmt->execute([$id]);
    $record = $stmt->fetch();

    if (!$record) {
        $_SESSION['error'] = "找不到该入库记录";
        header("Location: material_receiving.php");
        exit;
    }
} catch (PDOException $e) {
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
    header("Location: material_receiving.php");
    exit;
}

// 质检结果映射
$qualityResultDisplay = [
    'passed' => ['text' => '通过', 'class' => '已完成'],
    'failed' => ['text' => '不合格', 'class' => '待处理'],
    'pending' => ['text' => '待检验', 'class' => '进行中']
];

$qualityInfo = $qualityResultDisplay[$record['quality_check_result']] ?? ['text' => $record['quality_check_result'], 'class' => ''];
?>

<!DOCTYPE html>
<html>

<head>
    <title>入库记录详情</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .record-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-bottom: 20px;
        }

        .record-info {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 15px;
        }

        .info-group {
            margin-bottom: 10px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
            margin-bottom: 5px;
        }

        .info-value {
            color: #333;
        }

        .info-notes {
            grid-column: span 2;
            background-color: #fff;
            padding: 15px;
            border-radius: 6px;
            border: 1px solid #ddd;
            margin-top: 10px;
        }

        .notes-title {
            font-weight: bold;
            margin-bottom: 10px;
            color: #2c3e50;
        }
    </style>
</head>

<body>
    <div class="container">
        <div class="record-header">
            <h2>入库记录详情</h2>
            <div>
                <?php if ($record['purchase_order_id']): ?>
                    <a href="purchase_order_detail.php?id=<?= $record['purchase_order_id'] ?>" class="btn" style="background-color: #6c757d;">查看采购订单</a>
                <?php endif; ?>
                <a href="material_receiving.php" class="btn" style="background-color: #6c757d;">返回列表</a>
            </div>
        </div>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="record-info">
            <div class="info-group">
                <div class="info-label">批次号</div>
                <div class="info-value"><?= htmlspecialchars($record['batch_number']) ?></div>
            </div>

            <div class="info-group">
                <div class="info-label">质检结果</div>
                <div class="info-value">
                    <span class="status-tag <?= $qualityInfo['class'] ?>"><?= $qualityInfo['text'] ?></span>
                </div>
            </div>

            <div class="info-group">
                <div class="info-label">产品名称</div>
                <div class="info-value"><?= htmlspecialchars($record['product_name']) ?></div>
            </div>

            <?php if ($record['specification']): ?>
                <div class="info-group">
                    <div class="info-label">规格</div>
                    <div class="info-value"><?= htmlspecialchars($record['specification']) ?></div>
                </div>
            <?php endif; ?>

            <div class="info-group">
                <div class="info-label">入库数量</div>
                <div class="info-value"><?= number_format($record['received_quantity'], 2) ?> <?= htmlspecialchars($record['unit']) ?></div>
            </div>

            <div class="info-group">
                <div class="info-label">入库日期</div>
                <div class="info-value"><?= date('Y-m-d H:i', strtotime($record['received_date'])) ?></div>
            </div>

            <div class="info-group">
                <div class="info-label">存放位置</div>
                <div class="info-value"><?= htmlspecialchars($record['location_name'] ?? '未指定') ?></div>
            </div>

            <div class="info-group">
                <div class="info-label">检验员</div>
                <div class="info-value"><?= htmlspecialchars($record['inspector_name'] ?? '未指定') ?></div>
            </div>

            <div class="info-group">
                <div class="info-label">采购订单</div>
                <div class="info-value">
                    <?php if ($record['order_number']): ?>
                        订单 <?= htmlspecialchars($record['order_number']) ?>
                        (<?= htmlspecialchars($record['supplier_name']) ?>)
                    <?php else: ?>
                        直接入库 (无关联订单)
                    <?php endif; ?>
                </div>
            </div>

            <?php if ($record['inspection_notes']): ?>
                <div class="info-notes">
                    <div class="notes-title">检验备注</div>
                    <div><?= nl2br(htmlspecialchars($record['inspection_notes'])) ?></div>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>