<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 检查审核权限（假设角色ID 1和2有权限）
if ($_SESSION['role_id'] != 1 && $_SESSION['role_id'] != 2) {
    $_SESSION['error'] = "您没有权限审核采购订单";
    header("Location: purchase_orders.php");
    exit;
}

// 获取订单ID
$order_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$order_id) {
    $_SESSION['error'] = "未指定订单ID";
    header("Location: purchase_orders.php");
    exit;
}

try {
    // 获取采购订单信息
    $stmt = $pdo->prepare("
        SELECT 
            po.id, 
            po.order_number, 
            po.status, 
            po.total_amount,
            s.name AS supplier_name
        FROM purchase_orders po
        JOIN suppliers s ON po.supplier_id = s.id
        WHERE po.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        $_SESSION['error'] = "找不到该采购订单";
        header("Location: purchase_orders.php");
        exit;
    }

    // 检查订单状态是否为待审批
    if ($order['status'] !== 'pending') {
        $_SESSION['error'] = "只有待审批状态的订单可以审核";
        header("Location: purchase_order_detail.php?id=" . $order_id);
        exit;
    }

    // 如果是POST请求，处理审核
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // CSRF验证
        if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
            $_SESSION['error'] = "安全验证失败，请重试";
            header("Location: purchase_order_approve.php?id=" . $order_id);
            exit;
        }

        $approval_status = $_POST['approval_status'] ?? '';
        $remarks = trim($_POST['remarks'] ?? '');

        if (!in_array($approval_status, ['approved', 'ordered', 'cancelled'])) {
            $_SESSION['error'] = "无效的审核状态";
            header("Location: purchase_order_approve.php?id=" . $order_id);
            exit;
        }

        $pdo->beginTransaction();

        // 更新订单状态
        $stmt = $pdo->prepare("
            UPDATE purchase_orders 
            SET status = ? 
            WHERE id = ?
        ");
        $stmt->execute([$approval_status, $order_id]);

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '审核采购订单',
            'purchase_order',
            $order_id,
            json_encode([
                'order_number' => $order['order_number'],
                'status' => $approval_status,
                'remarks' => $remarks
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();

        $statusText = [
            'approved' => '已批准',
            'ordered' => '已下单',
            'cancelled' => '已取消'
        ][$approval_status];

        $_SESSION['success'] = "采购订单 {$order['order_number']} 已{$statusText}";
        header("Location: purchase_order_detail.php?id=" . $order_id);
        exit;
    }
} catch (PDOException $e) {
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
    header("Location: purchase_orders.php");
    exit;
}
?>

<!DOCTYPE html>
<html>

<head>
    <title>审核采购订单</title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="container">
        <h2>审核采购订单</h2>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <div class="form-info">
            <div class="form-info-title">订单信息</div>
            <div><strong>订单编号:</strong> <?= htmlspecialchars($order['order_number']) ?></div>
            <div><strong>供应商:</strong> <?= htmlspecialchars($order['supplier_name']) ?></div>
            <div><strong>总金额:</strong> ¥<?= number_format($order['total_amount'], 2) ?></div>
            <div><strong>当前状态:</strong> 待审批</div>
        </div>

        <div class="form-container">
            <form method="POST">
                <?= csrf_field() ?>

                <div class="form-group">
                    <label>审核决定</label>
                    <div class="radio-group">
                        <div class="radio-option">
                            <input type="radio" id="approved" name="approval_status" value="approved" checked>
                            <label for="approved">批准</label>
                        </div>
                        <div class="radio-option">
                            <input type="radio" id="ordered" name="approval_status" value="ordered">
                            <label for="ordered">批准并标记为已下单</label>
                        </div>
                        <div class="radio-option">
                            <input type="radio" id="cancelled" name="approval_status" value="cancelled">
                            <label for="cancelled">拒绝并取消</label>
                        </div>
                    </div>
                </div>

                <div class="form-group">
                    <label>审核备注</label>
                    <textarea name="remarks" rows="4" placeholder="输入审核相关备注信息"></textarea>
                </div>

                <div class="form-group">
                    <button type="submit" class="btn">提交审核结果</button>
                    <a href="purchase_order_detail.php?id=<?= $order_id ?>" class="btn" style="background-color: #6c757d; margin-left: 10px;">返回详情</a>
                </div>
            </form>
        </div>
    </div>

    <style>
        .form-info {
            background-color: #f8f9fa;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 20px;
        }

        .form-info-title {
            font-weight: bold;
            margin-bottom: 10px;
            color: #2c3e50;
        }

        .radio-group {
            display: flex;
            flex-direction: column;
            gap: 10px;
            margin: 10px 0;
        }

        .radio-option {
            display: flex;
            align-items: center;
            gap: 5px;
        }
    </style>
</body>

</html>