<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 设置分页参数
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// 构建筛选条件
$where_clauses = [];
$params = [];

// 用户筛选
if (isset($_GET['user_id']) && $_GET['user_id'] > 0) {
    $where_clauses[] = "user_id = ?";
    $params[] = $_GET['user_id'];
}

// 操作类型筛选
if (isset($_GET['action']) && !empty($_GET['action'])) {
    $where_clauses[] = "action = ?";
    $params[] = $_GET['action'];
}

// 目标类型筛选
if (isset($_GET['target_type']) && !empty($_GET['target_type'])) {
    $where_clauses[] = "target_type = ?";
    $params[] = $_GET['target_type'];
}

// 日期范围筛选
if (isset($_GET['start_date']) && !empty($_GET['start_date'])) {
    $where_clauses[] = "timestamp >= ?";
    $params[] = $_GET['start_date'] . ' 00:00:00';
}

if (isset($_GET['end_date']) && !empty($_GET['end_date'])) {
    $where_clauses[] = "timestamp <= ?";
    $params[] = $_GET['end_date'] . ' 23:59:59';
}

// 构建WHERE子句
$where_sql = '';
if (!empty($where_clauses)) {
    $where_sql = "WHERE " . implode(" AND ", $where_clauses);
}

// 获取总记录数
$count_sql = "SELECT COUNT(*) FROM activity_log $where_sql";
$stmt = $pdo->prepare($count_sql);
$stmt->execute($params);
$total_records = $stmt->fetchColumn();

// 计算总页数
$total_pages = ceil($total_records / $limit);
if ($page > $total_pages) {
    $page = $total_pages;
}
if ($page < 1) {
    $page = 1;
}

// 获取日志记录
$sql = "
    SELECT * FROM activity_log 
    $where_sql
    ORDER BY timestamp DESC 
    LIMIT $offset, $limit
";
$stmt = $pdo->prepare($sql);
$stmt->execute($params);
$logs = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取所有用户，用于筛选
$users = $pdo->query("SELECT id, username FROM users ORDER BY username")->fetchAll();

// 获取所有操作类型，用于筛选
$actions = $pdo->query("SELECT DISTINCT action FROM activity_log ORDER BY action")->fetchAll(PDO::FETCH_COLUMN);

// 获取所有目标类型，用于筛选
$target_types = $pdo->query("SELECT DISTINCT target_type FROM activity_log WHERE target_type IS NOT NULL ORDER BY target_type")->fetchAll(PDO::FETCH_COLUMN);
?>
<!DOCTYPE html>
<html>

<head>
    <title>操作日志 - 果易管系统</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .filter-form {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 20px;
        }

        .filter-form .form-group {
            flex: 1;
            min-width: 200px;
            margin-bottom: 0;
        }

        .filter-form .form-group label {
            font-size: 0.9rem;
            margin-bottom: 5px;
        }

        .filter-form .form-group select,
        .filter-form .form-group input {
            padding: 8px;
            width: 100%;
        }

        .pagination {
            display: flex;
            justify-content: center;
            margin-top: 20px;
            gap: 5px;
        }

        .pagination a {
            padding: 8px 12px;
            border: 1px solid #ddd;
            color: #333;
            text-decoration: none;
            border-radius: 4px;
        }

        .pagination a.active {
            background-color: #007bff;
            color: white;
            border-color: #007bff;
        }

        .pagination a:hover:not(.active) {
            background-color: #f5f5f5;
        }

        .details-cell {
            max-width: 400px;
            word-break: break-word;
        }

        .log-table td {
            vertical-align: top;
            padding: 10px;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>系统操作日志</h2>

        <!-- 筛选表单 -->
        <div class="form-container">
            <form method="GET" class="filter-form">
                <div class="form-group">
                    <label>用户</label>
                    <select name="user_id">
                        <option value="">所有用户</option>
                        <?php foreach ($users as $user): ?>
                            <option value="<?= $user['id'] ?>" <?= isset($_GET['user_id']) && $_GET['user_id'] == $user['id'] ? 'selected' : '' ?>>
                                <?= htmlspecialchars($user['username']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>操作类型</label>
                    <select name="action">
                        <option value="">所有操作</option>
                        <?php foreach ($actions as $action): ?>
                            <option value="<?= $action ?>" <?= isset($_GET['action']) && $_GET['action'] == $action ? 'selected' : '' ?>>
                                <?= htmlspecialchars($action) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>目标类型</label>
                    <select name="target_type">
                        <option value="">所有类型</option>
                        <?php foreach ($target_types as $type): ?>
                            <option value="<?= $type ?>" <?= isset($_GET['target_type']) && $_GET['target_type'] == $type ? 'selected' : '' ?>>
                                <?= htmlspecialchars($type) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-group">
                    <label>开始日期</label>
                    <input type="date" name="start_date" value="<?= isset($_GET['start_date']) ? htmlspecialchars($_GET['start_date']) : '' ?>">
                </div>

                <div class="form-group">
                    <label>结束日期</label>
                    <input type="date" name="end_date" value="<?= isset($_GET['end_date']) ? htmlspecialchars($_GET['end_date']) : '' ?>">
                </div>

                <div class="form-group" style="display: flex; align-items: flex-end;">
                    <button type="submit" class="btn">筛选</button>
                    <a href="activity_log.php" class="btn-secondary" style="margin-left: 10px;">重置</a>
                </div>
            </form>
        </div>

        <!-- 日志列表 -->
        <div class="table-container">
            <table class="log-table">
                <thead>
                    <tr>
                        <th>时间</th>
                        <th>用户</th>
                        <th>操作</th>
                        <th>目标类型</th>
                        <th>目标ID</th>
                        <th>IP地址</th>
                        <th>详情</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($logs)): ?>
                        <tr>
                            <td colspan="7" class="empty-state">无符合条件的日志记录</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($logs as $log): ?>
                            <tr>
                                <td><?= date('Y-m-d H:i:s', strtotime($log['timestamp'])) ?></td>
                                <td><?= htmlspecialchars($log['username']) ?></td>
                                <td><?= htmlspecialchars($log['action']) ?></td>
                                <td><?= htmlspecialchars($log['target_type'] ?? '-') ?></td>
                                <td><?= $log['target_id'] ? htmlspecialchars($log['target_id']) : '-' ?></td>
                                <td><?= htmlspecialchars($log['ip_address']) ?></td>
                                <td class="details-cell">
                                    <?php
                                    $details = json_decode($log['details'], true);
                                    if (is_array($details)) {
                                        echo '<ul style="margin: 0; padding-left: 20px;">';
                                        foreach ($details as $key => $value) {
                                            if (is_array($value)) {
                                                $value = json_encode($value, JSON_UNESCAPED_UNICODE);
                                            }
                                            echo '<li>' . htmlspecialchars($key) . ': ' . htmlspecialchars($value) . '</li>';
                                        }
                                        echo '</ul>';
                                    } else {
                                        echo htmlspecialchars($log['details'] ?? '-');
                                    }
                                    ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>

            <!-- 分页控件 -->
            <?php if ($total_pages > 1): ?>
                <div class="pagination">
                    <?php if ($page > 1): ?>
                        <a href="?page=1<?= $this->buildQueryString(['page']) ?>">首页</a>
                        <a href="?page=<?= $page - 1 ?><?= $this->buildQueryString(['page']) ?>">上一页</a>
                    <?php endif; ?>

                    <?php
                    $start_page = max(1, $page - 2);
                    $end_page = min($start_page + 4, $total_pages);
                    if ($end_page - $start_page < 4) {
                        $start_page = max(1, $end_page - 4);
                    }
                    ?>

                    <?php for ($i = $start_page; $i <= $end_page; $i++): ?>
                        <a href="?page=<?= $i ?><?= $this->buildQueryString(['page']) ?>"
                            class="<?= $i == $page ? 'active' : '' ?>">
                            <?= $i ?>
                        </a>
                    <?php endfor; ?>

                    <?php if ($page < $total_pages): ?>
                        <a href="?page=<?= $page + 1 ?><?= $this->buildQueryString(['page']) ?>">下一页</a>
                        <a href="?page=<?= $total_pages ?><?= $this->buildQueryString(['page']) ?>">末页</a>
                    <?php endif; ?>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 格式化日期函数
        function formatDate(date) {
            return date ? new Date(date).toISOString().split('T')[0] : '';
        }

        // 设置默认筛选日期为近7天
        document.addEventListener('DOMContentLoaded', function() {
            const startDateInput = document.querySelector('input[name="start_date"]');
            const endDateInput = document.querySelector('input[name="end_date"]');

            // 只有当URL中没有指定日期时，才设置默认值
            if (!startDateInput.value && startDateInput.value === '') {
                const today = new Date();
                const sevenDaysAgo = new Date();
                sevenDaysAgo.setDate(today.getDate() - 7);

                startDateInput.value = formatDate(sevenDaysAgo);
                endDateInput.value = formatDate(today);
            }
        });
    </script>
</body>

</html>

<?php
// 辅助函数，构建查询字符串
function buildQueryString($excludeParams = [])
{
    $params = $_GET;
    foreach ($excludeParams as $param) {
        unset($params[$param]);
    }

    if (empty($params)) {
        return '';
    }

    return '&' . http_build_query($params);
}
?>